
package ONVIF::Device::Typemaps::Device;
use strict;
use warnings;

our $typemap_1 = {
               'GetNetworkInterfacesResponse/NetworkInterfaces/Extension/Dot11/Alias' => 'ONVIF::Device::Types::Name',
               'RestoreSystemResponse' => 'ONVIF::Device::Elements::RestoreSystemResponse',
               'GetNTPResponse/NTPInformation/NTPManual/Extension' => 'ONVIF::Device::Types::NetworkHostExtension',
               'CreateDot1XConfiguration' => 'ONVIF::Device::Elements::CreateDot1XConfiguration',
               'GetCapabilities/Category' => 'ONVIF::Device::Types::CapabilityCategory',
               'SetCertificatesStatus/CertificateStatus' => 'ONVIF::Device::Types::CertificateStatus',
               'CreateCertificateResponse/NvtCertificate/Certificate' => 'ONVIF::Device::Types::BinaryData',
               'RemoveScopes' => 'ONVIF::Device::Elements::RemoveScopes',
               'SetNetworkInterfaces/NetworkInterface/Extension/Dot11/Security/PSK/Key' => 'ONVIF::Device::Types::Dot11PSK',
               'GetRemoteUserResponse/RemoteUser/Password' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'SetNetworkInterfaces/NetworkInterface/Extension/Dot11' => 'ONVIF::Device::Types::Dot11Configuration',
               'SetNetworkInterfaces/InterfaceToken' => 'ONVIF::Device::Types::ReferenceToken',
               'GetCapabilitiesResponse/Capabilities/Device/Network/Extension/Extension' => 'ONVIF::Device::Types::NetworkCapabilitiesExtension2',
               'GetIPAddressFilterResponse/IPAddressFilter/IPv6Address' => 'ONVIF::Device::Types::PrefixedIPv6Address',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Extension/Dot11/Mode' => 'ONVIF::Device::Types::Dot11StationMode',
               'ScanAvailableDot11NetworksResponse/Networks/SSID' => 'ONVIF::Device::Types::Dot11SSIDType',
               'SetHostnameFromDHCPResponse' => 'ONVIF::Device::Elements::SetHostnameFromDHCPResponse',
               'SetNetworkInterfaces/NetworkInterface/Link/Duplex' => 'ONVIF::Device::Types::Duplex',
               'GetCapabilitiesResponse/Capabilities/Media/StreamingCapabilities/RTP_RTSP_TCP' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv4/Config' => 'ONVIF::Device::Types::IPv4Configuration',
               'SetHostnameFromDHCP/FromDHCP' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'LoadCertificates' => 'ONVIF::Device::Elements::LoadCertificates',
               'DeleteUsersResponse' => 'ONVIF::Device::Elements::DeleteUsersResponse',
               'CreateUsersResponse' => 'ONVIF::Device::Elements::CreateUsersResponse',
               'CreateDot1XConfiguration/Dot1XConfiguration/Extension' => 'ONVIF::Device::Types::Dot1XConfigurationExtension',
               'GetDPAddressesResponse/DPAddress/IPv4Address' => 'ONVIF::Device::Types::IPv4Address',
               'StartFirmwareUpgradeResponse/UploadUri' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'SetRemoteDiscoveryModeResponse' => 'ONVIF::Device::Elements::SetRemoteDiscoveryModeResponse',
               'CreateDot1XConfiguration/Dot1XConfiguration' => 'ONVIF::Device::Types::Dot1XConfiguration',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Link/OperSettings/Speed' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetCertificateInformationResponse/CertificateInformation/Extension' => 'ONVIF::Device::Types::CertificateInformationExtension',
               'GetCapabilitiesResponse/Capabilities/Media/StreamingCapabilities/RTP_TCP' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetRelayOutputSettingsResponse' => 'ONVIF::Device::Elements::SetRelayOutputSettingsResponse',
               'GetCapabilitiesResponse/Capabilities/Extension/Receiver/XAddr' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'SetNetworkInterfaces/NetworkInterface/IPv4/Enabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetCapabilitiesResponse/Capabilities/Media/StreamingCapabilities/Extension' => 'ONVIF::Device::Types::RealTimeStreamingCapabilitiesExtension',
               'AddIPAddressFilter' => 'ONVIF::Device::Elements::AddIPAddressFilter',
               'GetSystemUrisResponse/SystemLogUris' => 'ONVIF::Device::Types::SystemLogUriList',
               'SetNetworkInterfaces/NetworkInterface' => 'ONVIF::Device::Types::NetworkInterfaceSetConfiguration',
               'SetNetworkInterfaces/NetworkInterface/Link' => 'ONVIF::Device::Types::NetworkInterfaceConnectionSetting',
               'CreateCertificateResponse/NvtCertificate' => 'ONVIF::Device::Types::Certificate',
               'SetIPAddressFilter' => 'ONVIF::Device::Elements::SetIPAddressFilter',
               'RemoveScopesResponse' => 'ONVIF::Device::Elements::RemoveScopesResponse',
               'GetCertificatesStatusResponse/CertificateStatus/Status' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetCapabilitiesResponse/Capabilities/Extension/AnalyticsDevice' => 'ONVIF::Device::Types::AnalyticsDeviceCapabilities',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv4/Enabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetNTP/NTPManual' => 'ONVIF::Device::Types::NetworkHost',
               'SetIPAddressFilter/IPAddressFilter/IPv6Address/Address' => 'ONVIF::Device::Types::IPv6Address',
               'GetDot1XConfigurationResponse/Dot1XConfiguration/AnonymousID' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'LoadCACertificatesResponse' => 'ONVIF::Device::Elements::LoadCACertificatesResponse',
               'GetSystemLogResponse/SystemLog/Binary/Include' => 'ONVIF::Device::Types::Include',
               'GetNTPResponse/NTPInformation/NTPFromDHCP/Type' => 'ONVIF::Device::Types::NetworkHostType',
               'GetIPAddressFilterResponse/IPAddressFilter/IPv6Address/Address' => 'ONVIF::Device::Types::IPv6Address',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Extension/Dot11/Security' => 'ONVIF::Device::Types::Dot11SecurityConfiguration',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Extension/Dot11/Security/PSK/Extension' => 'ONVIF::Device::Types::Dot11PSKSetExtension',
               'GetNTPResponse/NTPInformation/NTPManual/IPv6Address' => 'ONVIF::Device::Types::IPv6Address',
               'GetPkcs10Request/Attributes' => 'ONVIF::Device::Types::BinaryData',
               'GetCapabilitiesResponse/Capabilities/Extension/Display' => 'ONVIF::Device::Types::DisplayCapabilities',
               'GetDot1XConfigurationResponse/Dot1XConfiguration/Extension' => 'ONVIF::Device::Types::Dot1XConfigurationExtension',
               'SetSystemDateAndTime/UTCDateTime/Time' => 'ONVIF::Device::Types::Time',
               'SetSystemDateAndTime/TimeZone' => 'ONVIF::Device::Types::TimeZone',
               'GetCertificatesStatusResponse' => 'ONVIF::Device::Elements::GetCertificatesStatusResponse',
               'GetDot1XConfigurationResponse/Dot1XConfiguration/EAPMethodConfiguration/Extension' => 'ONVIF::Device::Types::EapMethodExtension',
               'GetCapabilitiesResponse/Capabilities/Extension/Recording/DynamicTracks' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetSystemSupportInformationResponse' => 'ONVIF::Device::Elements::GetSystemSupportInformationResponse',
               'GetDot1XConfigurationResponse/Dot1XConfiguration/EAPMethodConfiguration/TLSConfiguration' => 'ONVIF::Device::Types::TLSConfiguration',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv6/Config/FromDHCP' => 'ONVIF::Device::Types::PrefixedIPv6Address',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/UTCDateTime/Date/Month' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetNetworkInterfaces/NetworkInterface/IPv4/DHCP' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'AddIPAddressFilter/IPAddressFilter/IPv6Address/Address' => 'ONVIF::Device::Types::IPv6Address',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv6/Config/Manual/PrefixLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Extension/Dot11/Security/Extension' => 'ONVIF::Device::Types::Dot11SecurityConfigurationExtension',
               'StartFirmwareUpgrade' => 'ONVIF::Device::Elements::StartFirmwareUpgrade',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv6/Config/Extension' => 'ONVIF::Device::Types::IPv6ConfigurationExtension',
               'SetUser/User' => 'ONVIF::Device::Types::User',
               'SetNetworkInterfaces/NetworkInterface/IPv6/Enabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetDNSResponse/DNSInformation/DNSManual' => 'ONVIF::Device::Types::IPAddress',
               'GetCapabilitiesResponse/Capabilities/Device/System/DiscoveryResolve' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetNetworkInterfaces/NetworkInterface/Extension/Dot11/Security/Algorithm' => 'ONVIF::Device::Types::Dot11Cipher',
               'GetCertificatesStatus' => 'ONVIF::Device::Elements::GetCertificatesStatus',
               'SetUser/User/UserLevel' => 'ONVIF::Device::Types::UserLevel',
               'SetDot1XConfiguration/Dot1XConfiguration/EAPMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetHostnameResponse/HostnameInformation' => 'ONVIF::Device::Types::HostnameInformation',
               'CreateCertificateResponse/NvtCertificate/Certificate/Data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'StartFirmwareUpgradeResponse/ExpectedDownTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetScopes' => 'ONVIF::Device::Elements::GetScopes',
               'GetDiscoveryModeResponse' => 'ONVIF::Device::Elements::GetDiscoveryModeResponse',
               'GetAccessPolicy' => 'ONVIF::Device::Elements::GetAccessPolicy',
               'GetZeroConfigurationResponse/ZeroConfiguration/Enabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetIPAddressFilterResponse/IPAddressFilter/IPv4Address/Address' => 'ONVIF::Device::Types::IPv4Address',
               'GetCapabilitiesResponse/Capabilities/Extension/Recording/DynamicRecordings' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetNetworkProtocols/NetworkProtocols/Name' => 'ONVIF::Device::Types::NetworkProtocolType',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv6/Config/AcceptRouterAdvert' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'RemoveIPAddressFilterResponse' => 'ONVIF::Device::Elements::RemoveIPAddressFilterResponse',
               'CreateUsers/User/Extension' => 'ONVIF::Device::Types::UserExtension',
               'GetDot1XConfigurationResponse/Dot1XConfiguration/EAPMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetDot11CapabilitiesResponse/Capabilities/MultipleConfiguration' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetIPAddressFilter/IPAddressFilter/IPv6Address' => 'ONVIF::Device::Types::PrefixedIPv6Address',
               'GetPkcs10RequestResponse/Pkcs10Request' => 'ONVIF::Device::Types::BinaryData',
               'GetCertificates' => 'ONVIF::Device::Elements::GetCertificates',
               'SetAccessPolicy/PolicyFile/Data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'GetSystemUrisResponse' => 'ONVIF::Device::Elements::GetSystemUrisResponse',
               'SetNetworkDefaultGateway/IPv6Address' => 'ONVIF::Device::Types::IPv6Address',
               'GetServiceCapabilitiesResponse' => 'ONVIF::Device::Elements::GetServiceCapabilitiesResponse',
               'SetNetworkInterfaces/NetworkInterface/IPv6/AcceptRouterAdvert' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetRelayOutputSettings/Properties' => 'ONVIF::Device::Types::RelayOutputSettings',
               'GetDynamicDNSResponse/DynamicDNSInformation/Name' => 'ONVIF::Device::Types::DNSName',
               'GetDot1XConfigurationResponse/Dot1XConfiguration' => 'ONVIF::Device::Types::Dot1XConfiguration',
               'GetNetworkDefaultGatewayResponse/NetworkGateway' => 'ONVIF::Device::Types::NetworkGateway',
               'SetClientCertificateMode' => 'ONVIF::Device::Elements::SetClientCertificateMode',
               'SetSystemDateAndTime/TimeZone/TZ' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'GetIPAddressFilterResponse/IPAddressFilter/IPv4Address/PrefixLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CreateDot1XConfiguration/Dot1XConfiguration/EAPMethodConfiguration/Password' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetCapabilitiesResponse/Capabilities/Extension/DeviceIO/AudioSources' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/UTCDateTime/Time' => 'ONVIF::Device::Types::Time',
               'AddScopes/ScopeItem' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Extension/Dot11/Security/PSK/Passphrase' => 'ONVIF::Device::Types::Dot11PSKPassphrase',
               'GetSystemBackupResponse/BackupFiles/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'SetRelayOutputSettings/Properties/Mode' => 'ONVIF::Device::Types::RelayMode',
               'SetNetworkInterfaces/NetworkInterface/Extension/Dot11/Security' => 'ONVIF::Device::Types::Dot11SecurityConfiguration',
               'SetSystemFactoryDefault' => 'ONVIF::Device::Elements::SetSystemFactoryDefault',
               'GetAccessPolicyResponse' => 'ONVIF::Device::Elements::GetAccessPolicyResponse',
               'SetHostnameFromDHCP' => 'ONVIF::Device::Elements::SetHostnameFromDHCP',
               'GetZeroConfigurationResponse/ZeroConfiguration' => 'ONVIF::Device::Types::NetworkZeroConfiguration',
               'RemoveIPAddressFilter/IPAddressFilter/IPv4Address/PrefixLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetSystemDateAndTime/UTCDateTime/Time/Hour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetNetworkInterfacesResponse/RebootNeeded' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetNetworkInterfaces/NetworkInterface/Extension/Extension' => 'ONVIF::Device::Types::NetworkInterfaceSetConfigurationExtension2',
               'SetUserResponse' => 'ONVIF::Device::Elements::SetUserResponse',
               'GetDNSResponse/DNSInformation' => 'ONVIF::Device::Types::DNSInformation',
               'GetCapabilitiesResponse/Capabilities/Device/System/Extension/HttpSystemBackup' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv6/Config/LinkLocal/Address' => 'ONVIF::Device::Types::IPv6Address',
               'GetDot11Capabilities' => 'ONVIF::Device::Elements::GetDot11Capabilities',
               'SetNTP/FromDHCP' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetCapabilitiesResponse/Capabilities/Media/Extension/ProfileCapabilities/MaximumNumberOfProfiles' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetRemoteUserResponse/RemoteUser' => 'ONVIF::Device::Types::RemoteUser',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/UTCDateTime/Date' => 'ONVIF::Device::Types::Date',
               'ScanAvailableDot11Networks/InterfaceToken' => 'ONVIF::Device::Types::ReferenceToken',
               'GetCapabilitiesResponse/Capabilities/Device/System/Extension/HttpFirmwareUpgrade' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetCertificatesResponse/NvtCertificate/CertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'SetNetworkInterfaces/NetworkInterface/Extension/Dot11/Security/PSK/Passphrase' => 'ONVIF::Device::Types::Dot11PSKPassphrase',
               'GetDot11Status' => 'ONVIF::Device::Elements::GetDot11Status',
               'GetDNS' => 'ONVIF::Device::Elements::GetDNS',
               'GetNetworkDefaultGatewayResponse/NetworkGateway/IPv4Address' => 'ONVIF::Device::Types::IPv4Address',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv4/Config/FromDHCP/Address' => 'ONVIF::Device::Types::IPv4Address',
               'SetIPAddressFilter/IPAddressFilter/Extension' => 'ONVIF::Device::Types::IPAddressFilterExtension',
               'ScanAvailableDot11NetworksResponse/Networks/AuthAndMangementSuite' => 'ONVIF::Device::Types::Dot11AuthAndMangementSuite',
               'GetCapabilitiesResponse/Capabilities/Device/Security/Extension' => 'ONVIF::Device::Types::SecurityCapabilitiesExtension',
               'GetClientCertificateMode' => 'ONVIF::Device::Elements::GetClientCertificateMode',
               'SetUser/User/Extension' => 'ONVIF::Device::Types::UserExtension',
               'SetNTP/NTPManual/Extension' => 'ONVIF::Device::Types::NetworkHostExtension',
               'SendAuxiliaryCommandResponse/AuxiliaryCommandResponse' => 'ONVIF::Device::Types::AuxiliaryData',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Link/OperSettings' => 'ONVIF::Device::Types::NetworkInterfaceConnectionSetting',
               'RemoveScopes/ScopeItem' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'CreateUsers/User' => 'ONVIF::Device::Types::User',
               'SetNetworkInterfaces/NetworkInterface/IPv6' => 'ONVIF::Device::Types::IPv6NetworkInterfaceSetConfiguration',
               'GetCapabilitiesResponse/Capabilities/Extension/DeviceIO' => 'ONVIF::Device::Types::DeviceIOCapabilities',
               'GetCertificateInformationResponse/CertificateInformation/SerialNum' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetDot11CapabilitiesResponse/Capabilities/ScanAvailableNetworks' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetCapabilitiesResponse/Capabilities/Device/IO/Extension' => 'ONVIF::Device::Types::IOCapabilitiesExtension',
               'GetPkcs10Request/Attributes/Data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'UpgradeSystemFirmwareResponse' => 'ONVIF::Device::Elements::UpgradeSystemFirmwareResponse',
               'GetSystemSupportInformationResponse/SupportInformation' => 'ONVIF::Device::Types::SupportInformation',
               'GetCapabilitiesResponse/Capabilities/Device/Network/DynDNS' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetIPAddressFilter/IPAddressFilter/IPv4Address' => 'ONVIF::Device::Types::PrefixedIPv4Address',
               'LoadCertificateWithPrivateKey/CertificateWithPrivateKey' => 'ONVIF::Device::Types::CertificateWithPrivateKey',
               'GetZeroConfigurationResponse/ZeroConfiguration/Extension' => 'ONVIF::Device::Types::NetworkZeroConfigurationExtension',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Extension/Dot11/Security/Algorithm' => 'ONVIF::Device::Types::Dot11Cipher',
               'GetDPAddressesResponse/DPAddress/Extension' => 'ONVIF::Device::Types::NetworkHostExtension',
               'CreateCertificate/ValidNotBefore' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'CreateDot1XConfiguration/Dot1XConfiguration/EAPMethodConfiguration/Extension' => 'ONVIF::Device::Types::EapMethodExtension',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv4/Config/LinkLocal/Address' => 'ONVIF::Device::Types::IPv4Address',
               'GetEndpointReferenceResponse/GUID' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CreateUsers/User/Username' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetServicesResponse/Service/Version' => 'ONVIF::Device::Types::OnvifVersion',
               'GetDot11CapabilitiesResponse/Capabilities' => 'ONVIF::Device::Types::Dot11Capabilities',
               'CreateDot1XConfigurationResponse' => 'ONVIF::Device::Elements::CreateDot1XConfigurationResponse',
               'GetCertificatesStatusResponse/CertificateStatus/CertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv4/Config/FromDHCP' => 'ONVIF::Device::Types::PrefixedIPv4Address',
               'SetDot1XConfiguration/Dot1XConfiguration/AnonymousID' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'UpgradeSystemFirmware/Firmware' => 'ONVIF::Device::Types::AttachmentData',
               'GetRelayOutputsResponse/RelayOutputs/Properties/DelayTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetHostname' => 'ONVIF::Device::Elements::GetHostname',
               'GetDot11CapabilitiesResponse/Capabilities/TKIP' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetDot1XConfiguration/Dot1XConfiguration/Extension' => 'ONVIF::Device::Types::Dot1XConfigurationExtension',
               'GetZeroConfigurationResponse/ZeroConfiguration/Extension/Extension' => 'ONVIF::Device::Types::NetworkZeroConfigurationExtension2',
               'GetCapabilitiesResponse/Capabilities/Device/System/SystemLogging' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetRemoteUser/RemoteUser/Username' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetCapabilities' => 'ONVIF::Device::Elements::GetCapabilities',
               'GetServiceCapabilitiesResponse/Capabilities/Network' => 'ONVIF::Device::Types::NetworkCapabilities',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Extension/Dot11/SSID' => 'ONVIF::Device::Types::Dot11SSIDType',
               'StartSystemRestoreResponse/UploadUri' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetCapabilitiesResponse/Capabilities/Events' => 'ONVIF::Device::Types::EventCapabilities',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Extension/Dot3' => 'ONVIF::Device::Types::Dot3Configuration',
               'GetPkcs10Request' => 'ONVIF::Device::Elements::GetPkcs10Request',
               'GetScopesResponse/Scopes' => 'ONVIF::Device::Types::Scope',
               'SetIPAddressFilter/IPAddressFilter/IPv4Address/PrefixLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetCapabilitiesResponse/Capabilities/Device/IO' => 'ONVIF::Device::Types::IOCapabilities',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/UTCDateTime/Date/Year' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetDPAddressesResponse/DPAddress/IPv6Address' => 'ONVIF::Device::Types::IPv6Address',
               'SetSystemDateAndTime/UTCDateTime/Date/Month' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetCapabilitiesResponse/Capabilities/Events/XAddr' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'StartFirmwareUpgradeResponse' => 'ONVIF::Device::Elements::StartFirmwareUpgradeResponse',
               'ScanAvailableDot11NetworksResponse/Networks/BSSID' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'AddIPAddressFilter/IPAddressFilter/IPv6Address/PrefixLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetSystemDateAndTimeResponse' => 'ONVIF::Device::Elements::SetSystemDateAndTimeResponse',
               'SetSystemDateAndTime/UTCDateTime/Time/Second' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetEndpointReferenceResponse' => 'ONVIF::Device::Elements::GetEndpointReferenceResponse',
               'GetCACertificatesResponse/CACertificate' => 'ONVIF::Device::Types::Certificate',
               'GetCapabilitiesResponse/Capabilities/Media/StreamingCapabilities/RTPMulticast' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetCertificateInformationResponse/CertificateInformation/KeyLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetNetworkInterfaces/NetworkInterface/Extension/Dot11/Security/PSK' => 'ONVIF::Device::Types::Dot11PSKSet',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/TimeZone' => 'ONVIF::Device::Types::TimeZone',
               'GetCertificateInformation' => 'ONVIF::Device::Elements::GetCertificateInformation',
               'SetRelayOutputState/LogicalState' => 'ONVIF::Device::Types::RelayLogicalState',
               'LoadCertificateWithPrivateKey/CertificateWithPrivateKey/CertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'SendAuxiliaryCommandResponse' => 'ONVIF::Device::Elements::SendAuxiliaryCommandResponse',
               'SetNetworkInterfaces/NetworkInterface/Extension/Dot11/Security/Dot1X' => 'ONVIF::Device::Types::ReferenceToken',
               'GetCapabilitiesResponse/Capabilities/Device/System/SupportedVersions/Major' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetCertificatesStatus/CertificateStatus/Status' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetAccessPolicy' => 'ONVIF::Device::Elements::SetAccessPolicy',
               'SetRelayOutputSettings/RelayOutputToken' => 'ONVIF::Device::Types::ReferenceToken',
               'LoadCACertificates' => 'ONVIF::Device::Elements::LoadCACertificates',
               'SetNetworkProtocols' => 'ONVIF::Device::Elements::SetNetworkProtocols',
               'GetDot1XConfigurationsResponse/Dot1XConfiguration/Identity' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetIPAddressFilter' => 'ONVIF::Device::Elements::GetIPAddressFilter',
               'DeleteCertificates' => 'ONVIF::Device::Elements::DeleteCertificates',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/LocalDateTime/Date' => 'ONVIF::Device::Types::Date',
               'SetCertificatesStatus/CertificateStatus/CertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'SendAuxiliaryCommand' => 'ONVIF::Device::Elements::SendAuxiliaryCommand',
               'SetNetworkInterfaces/NetworkInterface/IPv6/Manual/PrefixLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetDynamicDNSResponse' => 'ONVIF::Device::Elements::SetDynamicDNSResponse',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv6/Config/FromRA/Address' => 'ONVIF::Device::Types::IPv6Address',
               'GetServicesResponse/Service' => 'ONVIF::Device::Types::Service',
               'GetDot1XConfigurationResponse/Dot1XConfiguration/EAPMethodConfiguration/TLSConfiguration/CertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'GetDeviceInformationResponse/Model' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CreateDot1XConfiguration/Dot1XConfiguration/EAPMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetDot1XConfigurationsResponse/Dot1XConfiguration/EAPMethodConfiguration' => 'ONVIF::Device::Types::EAPMethodConfiguration',
               'ScanAvailableDot11Networks' => 'ONVIF::Device::Elements::ScanAvailableDot11Networks',
               'SetDNSResponse' => 'ONVIF::Device::Elements::SetDNSResponse',
               'DeleteDot1XConfigurationResponse' => 'ONVIF::Device::Elements::DeleteDot1XConfigurationResponse',
               'GetCapabilitiesResponse/Capabilities/Device/System/Extension/HttpSupportInformation' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetRelayOutputsResponse/RelayOutputs/Properties/Mode' => 'ONVIF::Device::Types::RelayMode',
               'GetCapabilitiesResponse/Capabilities/Device/System/DiscoveryBye' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetCapabilitiesResponse/Capabilities/Extension/Recording/MediaProfileSource' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetDot1XConfiguration/Dot1XConfigurationToken' => 'ONVIF::Device::Types::ReferenceToken',
               'GetCapabilitiesResponse/Capabilities/Device/Security/AccessPolicyConfig' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'AddIPAddressFilter/IPAddressFilter/Type' => 'ONVIF::Device::Types::IPAddressFilterType',
               'GetSystemUrisResponse/SystemLogUris/SystemLog' => 'ONVIF::Device::Types::SystemLogUri',
               'SetDPAddresses' => 'ONVIF::Device::Elements::SetDPAddresses',
               'GetDPAddressesResponse' => 'ONVIF::Device::Elements::GetDPAddressesResponse',
               'SetNTP' => 'ONVIF::Device::Elements::SetNTP',
               'GetCapabilitiesResponse/Capabilities/Extension/Search/MetadataSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetNetworkProtocols/NetworkProtocols' => 'ONVIF::Device::Types::NetworkProtocol',
               'GetWsdlUrl' => 'ONVIF::Device::Elements::GetWsdlUrl',
               'GetCapabilitiesResponse/Capabilities/Device/Security/Extension/Extension/Dot1X' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetRemoteUserResponse' => 'ONVIF::Device::Elements::GetRemoteUserResponse',
               'GetNetworkProtocolsResponse/NetworkProtocols/Name' => 'ONVIF::Device::Types::NetworkProtocolType',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv6' => 'ONVIF::Device::Types::IPv6NetworkInterface',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/TimeZone/TZ' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'DeleteUsers/Username' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'SetNetworkInterfaces/NetworkInterface/Extension/Dot11/Alias' => 'ONVIF::Device::Types::Name',
               'GetCapabilitiesResponse/Capabilities/Extension/Extensions' => 'ONVIF::Device::Types::CapabilitiesExtension2',
               'SetZeroConfiguration/Enabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/UTCDateTime' => 'ONVIF::Device::Types::DateTime',
               'GetCapabilitiesResponse/Capabilities/Device/XAddr' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'LoadCACertificates/CACertificate' => 'ONVIF::Device::Types::Certificate',
               'SetNetworkInterfaces/NetworkInterface/IPv4' => 'ONVIF::Device::Types::IPv4NetworkInterfaceSetConfiguration',
               'GetDot1XConfigurationsResponse' => 'ONVIF::Device::Elements::GetDot1XConfigurationsResponse',
               'GetCapabilitiesResponse/Capabilities/Extension/Search' => 'ONVIF::Device::Types::SearchCapabilities',
               'SetNTPResponse' => 'ONVIF::Device::Elements::SetNTPResponse',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Link/AdminSettings/Duplex' => 'ONVIF::Device::Types::Duplex',
               'GetCapabilitiesResponse/Capabilities/Device/Security/SAMLToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetServiceCapabilitiesResponse/Capabilities/System' => 'ONVIF::Device::Types::SystemCapabilities',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/UTCDateTime/Time/Minute' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetSystemDateAndTime/UTCDateTime/Time/Minute' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetScopes' => 'ONVIF::Device::Elements::SetScopes',
               'GetDot1XConfigurations' => 'ONVIF::Device::Elements::GetDot1XConfigurations',
               'GetDNSResponse/DNSInformation/DNSFromDHCP/IPv4Address' => 'ONVIF::Device::Types::IPv4Address',
               'LoadCertificates/NVTCertificate' => 'ONVIF::Device::Types::Certificate',
               'GetCapabilitiesResponse/Capabilities/Events/WSPausableSubscriptionManagerInterfaceSupport' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetServicesResponse/Service/Capabilities' => 'ONVIF::Device::Types::Service::_Capabilities',
               'SetRelayOutputStateResponse' => 'ONVIF::Device::Elements::SetRelayOutputStateResponse',
               'GetNetworkInterfacesResponse/NetworkInterfaces' => 'ONVIF::Device::Types::NetworkInterface',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Info/MTU' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetNetworkInterfaces/NetworkInterface/Enabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetNTPResponse/NTPInformation' => 'ONVIF::Device::Types::NTPInformation',
               'LoadCertificateWithPrivateKey/CertificateWithPrivateKey/PrivateKey/Data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'GetNTPResponse/NTPInformation/NTPManual' => 'ONVIF::Device::Types::NetworkHost',
               'GetNetworkProtocols' => 'ONVIF::Device::Elements::GetNetworkProtocols',
               'GetCapabilitiesResponse/Capabilities/Extension/Replay/XAddr' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'SetRemoteUser' => 'ONVIF::Device::Elements::SetRemoteUser',
               'SetNetworkProtocols/NetworkProtocols/Enabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetCapabilitiesResponse/Capabilities/Extension/DeviceIO/AudioOutputs' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetIPAddressFilterResponse/IPAddressFilter/IPv6Address/PrefixLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetClientCertificateModeResponse' => 'ONVIF::Device::Elements::SetClientCertificateModeResponse',
               'GetDNSResponse/DNSInformation/FromDHCP' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetCapabilitiesResponse/Capabilities/Device/Security/Extension/TLS1.0' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetDot1XConfigurationsResponse/Dot1XConfiguration/CACertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'LoadCertificates/NVTCertificate/Certificate' => 'ONVIF::Device::Types::BinaryData',
               'GetNTPResponse/NTPInformation/NTPFromDHCP/DNSname' => 'ONVIF::Device::Types::DNSName',
               'GetServiceCapabilitiesResponse/Capabilities' => 'ONVIF::Device::Types::DeviceServiceCapabilities',
               'GetNTPResponse' => 'ONVIF::Device::Elements::GetNTPResponse',
               'GetDot11StatusResponse/Status/SignalStrength' => 'ONVIF::Device::Types::Dot11SignalStrength',
               'GetDot11StatusResponse/Status/ActiveConfigAlias' => 'ONVIF::Device::Types::ReferenceToken',
               'RemoveIPAddressFilter/IPAddressFilter/IPv6Address/PrefixLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'DeleteCertificatesResponse' => 'ONVIF::Device::Elements::DeleteCertificatesResponse',
               'GetSystemUrisResponse/SystemBackupUri' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'SetNetworkInterfaces' => 'ONVIF::Device::Elements::SetNetworkInterfaces',
               'GetCapabilitiesResponse/Capabilities/PTZ/XAddr' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetDot11StatusResponse/Status/GroupCipher' => 'ONVIF::Device::Types::Dot11Cipher',
               'GetCertificateInformationResponse' => 'ONVIF::Device::Elements::GetCertificateInformationResponse',
               'GetRemoteDiscoveryModeResponse' => 'ONVIF::Device::Elements::GetRemoteDiscoveryModeResponse',
               'SetScopes/Scopes' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetNTPResponse/NTPInformation/NTPFromDHCP/IPv6Address' => 'ONVIF::Device::Types::IPv6Address',
               'GetCACertificatesResponse/CACertificate/Certificate/Data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'SetRelayOutputState/RelayOutputToken' => 'ONVIF::Device::Types::ReferenceToken',
               'GetCertificateInformationResponse/CertificateInformation/IssuerDN' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetCapabilitiesResponse/Capabilities/Device/System/SystemBackup' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/UTCDateTime/Date/Day' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetDeviceInformationResponse/HardwareId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetSystemSupportInformation' => 'ONVIF::Device::Elements::GetSystemSupportInformation',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/LocalDateTime/Date/Day' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetCapabilitiesResponse/Capabilities/Device/Network/Extension/Dot11Configuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'AddIPAddressFilterResponse' => 'ONVIF::Device::Elements::AddIPAddressFilterResponse',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'AddScopesResponse' => 'ONVIF::Device::Elements::AddScopesResponse',
               'SetNetworkInterfaces/NetworkInterface/IPv4/Manual/Address' => 'ONVIF::Device::Types::IPv4Address',
               'ScanAvailableDot11NetworksResponse' => 'ONVIF::Device::Elements::ScanAvailableDot11NetworksResponse',
               'GetCapabilitiesResponse/Capabilities/Extension/Receiver/RTP_RTSP_TCP' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'LoadCertificates/NVTCertificate/CertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'AddIPAddressFilter/IPAddressFilter/IPv4Address' => 'ONVIF::Device::Types::PrefixedIPv4Address',
               'GetCapabilitiesResponse/Capabilities/Device/System/Extension/Extension' => 'ONVIF::Device::Types::SystemCapabilitiesExtension2',
               'SetDNS/DNSManual/IPv4Address' => 'ONVIF::Device::Types::IPv4Address',
               'GetDynamicDNSResponse/DynamicDNSInformation' => 'ONVIF::Device::Types::DynamicDNSInformation',
               'SetAccessPolicy/PolicyFile' => 'ONVIF::Device::Types::BinaryData',
               'SetCertificatesStatus' => 'ONVIF::Device::Elements::SetCertificatesStatus',
               'SetZeroConfiguration' => 'ONVIF::Device::Elements::SetZeroConfiguration',
               'SetNetworkInterfaces/NetworkInterface/Extension' => 'ONVIF::Device::Types::NetworkInterfaceSetConfigurationExtension',
               'GetDot1XConfigurationsResponse/Dot1XConfiguration/EAPMethodConfiguration/TLSConfiguration/CertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'SetRelayOutputState' => 'ONVIF::Device::Elements::SetRelayOutputState',
               'GetCapabilitiesResponse/Capabilities/Device/Network' => 'ONVIF::Device::Types::NetworkCapabilities',
               'CreateCertificate/ValidNotAfter' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'GetDot1XConfigurationsResponse/Dot1XConfiguration/AnonymousID' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'RemoveIPAddressFilter/IPAddressFilter/IPv6Address' => 'ONVIF::Device::Types::PrefixedIPv6Address',
               'GetUsersResponse/User/UserLevel' => 'ONVIF::Device::Types::UserLevel',
               'GetCapabilitiesResponse/Capabilities/Extension/Receiver' => 'ONVIF::Device::Types::ReceiverCapabilities',
               'SetDPAddresses/DPAddress/IPv4Address' => 'ONVIF::Device::Types::IPv4Address',
               'SetDNS/FromDHCP' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetCapabilitiesResponse/Capabilities/Device/System/Extension' => 'ONVIF::Device::Types::SystemCapabilitiesExtension',
               'RestoreSystem/BackupFiles/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Link/OperSettings/AutoNegotiation' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetNetworkProtocolsResponse/NetworkProtocols/Enabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetCapabilitiesResponse/Capabilities/Device/Extension' => 'ONVIF::Device::Types::DeviceCapabilitiesExtension',
               'GetCapabilitiesResponse/Capabilities/Device/Network/IPFilter' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetSystemLogResponse/SystemLog/Binary' => 'ONVIF::Device::Types::AttachmentData',
               'SetRemoteUserResponse' => 'ONVIF::Device::Elements::SetRemoteUserResponse',
               'GetRelayOutputsResponse/RelayOutputs' => 'ONVIF::Device::Types::RelayOutput',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/LocalDateTime/Time/Second' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetHostname/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'GetAccessPolicyResponse/PolicyFile' => 'ONVIF::Device::Types::BinaryData',
               'GetRemoteUserResponse/RemoteUser/UseDerivedPassword' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Extension/Dot11/Security/PSK' => 'ONVIF::Device::Types::Dot11PSKSet',
               'GetCACertificatesResponse/CACertificate/Certificate' => 'ONVIF::Device::Types::BinaryData',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv6/Config/LinkLocal' => 'ONVIF::Device::Types::PrefixedIPv6Address',
               'SetHostnameResponse' => 'ONVIF::Device::Elements::SetHostnameResponse',
               'GetCapabilitiesResponse/Capabilities/Analytics' => 'ONVIF::Device::Types::AnalyticsCapabilities',
               'SetRemoteDiscoveryMode/RemoteDiscoveryMode' => 'ONVIF::Device::Types::DiscoveryMode',
               'GetDot1XConfigurationsResponse/Dot1XConfiguration/EAPMethodConfiguration/Password' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetServices/IncludeCapability' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetServicesResponse/Service/Namespace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetIPAddressFilterResponse/IPAddressFilter/IPv4Address' => 'ONVIF::Device::Types::PrefixedIPv4Address',
               'GetScopesResponse' => 'ONVIF::Device::Elements::GetScopesResponse',
               'GetDot1XConfigurationsResponse/Dot1XConfiguration/EAPMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetUsers' => 'ONVIF::Device::Elements::GetUsers',
               'SetNetworkProtocolsResponse' => 'ONVIF::Device::Elements::SetNetworkProtocolsResponse',
               'GetIPAddressFilterResponse/IPAddressFilter' => 'ONVIF::Device::Types::IPAddressFilter',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Extension/InterfaceType' => 'ONVIF::Device::Types::IANA_IfTypes',
               'GetIPAddressFilterResponse/IPAddressFilter/Type' => 'ONVIF::Device::Types::IPAddressFilterType',
               'GetSystemUrisResponse/SystemLogUris/SystemLog/Type' => 'ONVIF::Device::Types::SystemLogType',
               'SetDot1XConfigurationResponse' => 'ONVIF::Device::Elements::SetDot1XConfigurationResponse',
               'GetCertificatesResponse/NvtCertificate' => 'ONVIF::Device::Types::Certificate',
               'SetDiscoveryMode' => 'ONVIF::Device::Elements::SetDiscoveryMode',
               'RestoreSystem/BackupFiles/Data' => 'ONVIF::Device::Types::AttachmentData',
               'SetZeroConfiguration/InterfaceToken' => 'ONVIF::Device::Types::ReferenceToken',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Link/OperSettings/Duplex' => 'ONVIF::Device::Types::Duplex',
               'CreateDot1XConfiguration/Dot1XConfiguration/EAPMethodConfiguration' => 'ONVIF::Device::Types::EAPMethodConfiguration',
               'CreateCertificateResponse' => 'ONVIF::Device::Elements::CreateCertificateResponse',
               'SetDPAddresses/DPAddress/IPv6Address' => 'ONVIF::Device::Types::IPv6Address',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv4/Config/Manual' => 'ONVIF::Device::Types::PrefixedIPv4Address',
               'GetCapabilitiesResponse/Capabilities/Device/Network/IPVersion6' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Extension/Dot11/Security/Dot1X' => 'ONVIF::Device::Types::ReferenceToken',
               'SetRelayOutputSettings' => 'ONVIF::Device::Elements::SetRelayOutputSettings',
               'LoadCertificateWithPrivateKey/CertificateWithPrivateKey/PrivateKey' => 'ONVIF::Device::Types::BinaryData',
               'GetDot1XConfigurationsResponse/Dot1XConfiguration/EAPMethodConfiguration/TLSConfiguration' => 'ONVIF::Device::Types::TLSConfiguration',
               'GetIPAddressFilterResponse/IPAddressFilter/Extension' => 'ONVIF::Device::Types::IPAddressFilterExtension',
               'Fault/detail' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetCapabilitiesResponse/Capabilities/Extension/Recording/ReceiverSource' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'CreateUsers/User/UserLevel' => 'ONVIF::Device::Types::UserLevel',
               'SetNetworkInterfaces/NetworkInterface/Extension/Dot11/Security/Mode' => 'ONVIF::Device::Types::Dot11SecurityMode',
               'SetDot1XConfiguration/Dot1XConfiguration/Dot1XConfigurationToken' => 'ONVIF::Device::Types::ReferenceToken',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv6/Config/FromDHCP/Address' => 'ONVIF::Device::Types::IPv6Address',
               'GetCapabilitiesResponse/Capabilities/Extension/Receiver/RTP_Multicast' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetCertificateInformationResponse/CertificateInformation/KeyUsage' => 'ONVIF::Device::Types::CertificateUsage',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv6/Config/FromRA/PrefixLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetNetworkInterfaces' => 'ONVIF::Device::Elements::GetNetworkInterfaces',
               'GetCapabilitiesResponse/Capabilities/Media/StreamingCapabilities' => 'ONVIF::Device::Types::RealTimeStreamingCapabilities',
               'GetCapabilitiesResponse/Capabilities/Device/Security/Extension/Extension' => 'ONVIF::Device::Types::SecurityCapabilitiesExtension2',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/LocalDateTime/Date/Year' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetDPAddressesResponse/DPAddress/Type' => 'ONVIF::Device::Types::NetworkHostType',
               'GetRemoteUserResponse/RemoteUser/Username' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetCapabilitiesResponse/Capabilities/Extension/Replay' => 'ONVIF::Device::Types::ReplayCapabilities',
               'GetCapabilitiesResponse/Capabilities/Extension/Display/FixedLayout' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetCapabilitiesResponse/Capabilities/Device/IO/InputConnectors' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetSystemBackupResponse/BackupFiles/Data/Include' => 'ONVIF::Device::Types::Include',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Enabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'CreateCertificateResponse/NvtCertificate/CertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'GetDot1XConfigurationsResponse/Dot1XConfiguration/EAPMethodConfiguration/Extension' => 'ONVIF::Device::Types::EapMethodExtension',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv4/Config/Manual/PrefixLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetCapabilitiesResponse/Capabilities/Extension/Recording' => 'ONVIF::Device::Types::RecordingCapabilities',
               'GetCapabilitiesResponse/Capabilities/Device/Security/KerberosToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetPkcs10Request/Subject' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv4/Config/LinkLocal' => 'ONVIF::Device::Types::PrefixedIPv4Address',
               'GetDNSResponse/DNSInformation/DNSManual/IPv4Address' => 'ONVIF::Device::Types::IPv4Address',
               'GetServiceCapabilitiesResponse/Capabilities/Misc' => 'ONVIF::Device::Types::MiscCapabilities',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Info/HwAddress' => 'ONVIF::Device::Types::HwAddress',
               'GetCertificatesStatusResponse/CertificateStatus' => 'ONVIF::Device::Types::CertificateStatus',
               'SetDot1XConfiguration/Dot1XConfiguration/EAPMethodConfiguration/TLSConfiguration/CertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'LoadCACertificates/CACertificate/Certificate/Data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'SetIPAddressFilterResponse' => 'ONVIF::Device::Elements::SetIPAddressFilterResponse',
               'GetDot1XConfigurationResponse/Dot1XConfiguration/Dot1XConfigurationToken' => 'ONVIF::Device::Types::ReferenceToken',
               'GetCertificateInformationResponse/CertificateInformation/SignatureAlgorithm' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ScanAvailableDot11NetworksResponse/Networks/Extension' => 'ONVIF::Device::Types::Dot11AvailableNetworksExtension',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv6/Config/DHCP' => 'ONVIF::Device::Types::IPv6DHCPConfiguration',
               'LoadCACertificates/CACertificate/Certificate' => 'ONVIF::Device::Types::BinaryData',
               'SetDot1XConfiguration/Dot1XConfiguration/EAPMethodConfiguration' => 'ONVIF::Device::Types::EAPMethodConfiguration',
               'GetSystemUrisResponse/SystemLogUris/SystemLog/Uri' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'SetDot1XConfiguration/Dot1XConfiguration/EAPMethodConfiguration/Password' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'SystemRebootResponse' => 'ONVIF::Device::Elements::SystemRebootResponse',
               'SetIPAddressFilter/IPAddressFilter/Type' => 'ONVIF::Device::Types::IPAddressFilterType',
               'GetNetworkProtocolsResponse/NetworkProtocols' => 'ONVIF::Device::Types::NetworkProtocol',
               'GetCapabilitiesResponse/Capabilities/Device' => 'ONVIF::Device::Types::DeviceCapabilities',
               'SetNetworkInterfaces/NetworkInterface/IPv6/Manual/Address' => 'ONVIF::Device::Types::IPv6Address',
               'GetZeroConfiguration' => 'ONVIF::Device::Elements::GetZeroConfiguration',
               'UpgradeSystemFirmwareResponse/Message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetCapabilitiesResponse/Capabilities/Extension/Recording/XAddr' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv6/Config/FromDHCP/PrefixLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetDot11StatusResponse/Status/SSID' => 'ONVIF::Device::Types::Dot11SSIDType',
               'DeleteUsers' => 'ONVIF::Device::Elements::DeleteUsers',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Link' => 'ONVIF::Device::Types::NetworkInterfaceLink',
               'SetDNS/SearchDomain' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'SetDot1XConfiguration' => 'ONVIF::Device::Elements::SetDot1XConfiguration',
               'SetNetworkInterfaces/NetworkInterface/IPv6/Manual' => 'ONVIF::Device::Types::PrefixedIPv6Address',
               'GetDot1XConfigurationsResponse/Dot1XConfiguration' => 'ONVIF::Device::Types::Dot1XConfiguration',
               'GetCapabilitiesResponse/Capabilities/Device/Security/RELToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetSystemDateAndTime/UTCDateTime/Date/Day' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetDot11Status/InterfaceToken' => 'ONVIF::Device::Types::ReferenceToken',
               'SetHostname' => 'ONVIF::Device::Elements::SetHostname',
               'SetDot1XConfiguration/Dot1XConfiguration/EAPMethodConfiguration/TLSConfiguration' => 'ONVIF::Device::Types::TLSConfiguration',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv6/Config/Manual/Address' => 'ONVIF::Device::Types::IPv6Address',
               'GetDNSResponse/DNSInformation/Extension' => 'ONVIF::Device::Types::DNSInformationExtension',
               'AddIPAddressFilter/IPAddressFilter/Extension' => 'ONVIF::Device::Types::IPAddressFilterExtension',
               'SetNetworkInterfaces/NetworkInterface/Link/Speed' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetNTPResponse/NTPInformation/NTPFromDHCP' => 'ONVIF::Device::Types::NetworkHost',
               'GetCapabilitiesResponse/Capabilities/Analytics/RuleSupport' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'CreateCertificate' => 'ONVIF::Device::Elements::CreateCertificate',
               'SetSystemDateAndTime/UTCDateTime/Date' => 'ONVIF::Device::Types::Date',
               'GetNTPResponse/NTPInformation/NTPManual/DNSname' => 'ONVIF::Device::Types::DNSName',
               'SetNetworkInterfaces/NetworkInterface/MTU' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetScopesResponse/Scopes/ScopeItem' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'SetRelayOutputSettings/Properties/DelayTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/LocalDateTime/Date/Month' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetDPAddressesResponse/DPAddress/DNSname' => 'ONVIF::Device::Types::DNSName',
               'GetEndpointReference' => 'ONVIF::Device::Elements::GetEndpointReference',
               'SetClientCertificateMode/Enabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetCapabilitiesResponse/Capabilities/Extension' => 'ONVIF::Device::Types::CapabilitiesExtension',
               'GetCapabilitiesResponse/Capabilities/Extension/DeviceIO/XAddr' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetSystemDateAndTimeResponse' => 'ONVIF::Device::Elements::GetSystemDateAndTimeResponse',
               'SetDPAddresses/DPAddress' => 'ONVIF::Device::Types::NetworkHost',
               'GetWsdlUrlResponse' => 'ONVIF::Device::Elements::GetWsdlUrlResponse',
               'CreateUsers/User/Password' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'StartSystemRestoreResponse' => 'ONVIF::Device::Elements::StartSystemRestoreResponse',
               'SetRemoteUser/RemoteUser/Password' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'SetSystemFactoryDefault/FactoryDefault' => 'ONVIF::Device::Types::FactoryDefaultType',
               'GetCapabilitiesResponse/Capabilities/Device/Security/X.509Token' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetRelayOutputSettings/Properties/IdleState' => 'ONVIF::Device::Types::RelayIdleState',
               'GetUsersResponse/User/Password' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetDynamicDNS' => 'ONVIF::Device::Elements::GetDynamicDNS',
               'GetCapabilitiesResponse/Capabilities/Extension/Display/XAddr' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetCapabilitiesResponse/Capabilities/Device/IO/Extension/Auxiliary' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetDot1XConfigurationResponse' => 'ONVIF::Device::Elements::GetDot1XConfigurationResponse',
               'GetDot11CapabilitiesResponse/Capabilities/WEP' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetClientCertificateModeResponse/Enabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetDiscoveryMode/DiscoveryMode' => 'ONVIF::Device::Types::DiscoveryMode',
               'GetDPAddressesResponse/DPAddress' => 'ONVIF::Device::Types::NetworkHost',
               'ScanAvailableDot11NetworksResponse/Networks/GroupCipher' => 'ONVIF::Device::Types::Dot11Cipher',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Link/AdminSettings' => 'ONVIF::Device::Types::NetworkInterfaceConnectionSetting',
               'GetCapabilitiesResponse/Capabilities' => 'ONVIF::Device::Types::Capabilities',
               'GetDot1XConfigurationsResponse/Dot1XConfiguration/Extension' => 'ONVIF::Device::Types::Dot1XConfigurationExtension',
               'GetCapabilitiesResponse/Capabilities/Extension/DeviceIO/VideoSources' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetRelayOutputsResponse/RelayOutputs/Properties/IdleState' => 'ONVIF::Device::Types::RelayIdleState',
               'GetDot1XConfigurationResponse/Dot1XConfiguration/EAPMethodConfiguration/Password' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetNTPResponse/NTPInformation/NTPFromDHCP/IPv4Address' => 'ONVIF::Device::Types::IPv4Address',
               'GetSystemUrisResponse/Extension' => 'ONVIF::Device::Elements::GetSystemUrisResponse::_Extension',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetDNSResponse/DNSInformation/SearchDomain' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'GetRemoteUser' => 'ONVIF::Device::Elements::GetRemoteUser',
               'GetSystemSupportInformationResponse/SupportInformation/String' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetHostnameResponse/HostnameInformation/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'GetSystemDateAndTimeResponse/SystemDateAndTime' => 'ONVIF::Device::Types::SystemDateTime',
               'GetCertificateInformationResponse/CertificateInformation' => 'ONVIF::Device::Types::CertificateInformation',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/UTCDateTime/Time/Hour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetCapabilitiesResponse/Capabilities/Analytics/AnalyticsModuleSupport' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetNTP/NTPManual/IPv6Address' => 'ONVIF::Device::Types::IPv6Address',
               'GetRemoteDiscoveryModeResponse/RemoteDiscoveryMode' => 'ONVIF::Device::Types::DiscoveryMode',
               'RemoveIPAddressFilter/IPAddressFilter/Type' => 'ONVIF::Device::Types::IPAddressFilterType',
               'SetNetworkInterfaces/NetworkInterface/Extension/Dot11/Mode' => 'ONVIF::Device::Types::Dot11StationMode',
               'SetSystemDateAndTime/UTCDateTime/Date/Year' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Link/AdminSettings/AutoNegotiation' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetCertificateInformation/CertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'LoadCertificateWithPrivateKeyResponse' => 'ONVIF::Device::Elements::LoadCertificateWithPrivateKeyResponse',
               'UpgradeSystemFirmware' => 'ONVIF::Device::Elements::UpgradeSystemFirmware',
               'StartSystemRestoreResponse/ExpectedDownTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'SetUser' => 'ONVIF::Device::Elements::SetUser',
               'RemoveIPAddressFilter/IPAddressFilter' => 'ONVIF::Device::Types::IPAddressFilter',
               'GetCapabilitiesResponse/Capabilities/Device/Security/Extension/Extension/SupportedEAPMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetCertificateInformationResponse/CertificateInformation/SubjectDN' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'SetDPAddresses/DPAddress/Extension' => 'ONVIF::Device::Types::NetworkHostExtension',
               'SetHostnameFromDHCPResponse/RebootNeeded' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetDNSResponse' => 'ONVIF::Device::Elements::GetDNSResponse',
               'GetCertificateInformationResponse/CertificateInformation/Version' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/LocalDateTime/Time/Hour' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetDot11CapabilitiesResponse' => 'ONVIF::Device::Elements::GetDot11CapabilitiesResponse',
               'GetServices' => 'ONVIF::Device::Elements::GetServices',
               'GetServicesResponse/Service/Version/Minor' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetCapabilitiesResponse/Capabilities/Imaging/XAddr' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetNetworkDefaultGatewayResponse' => 'ONVIF::Device::Elements::GetNetworkDefaultGatewayResponse',
               'SetDot1XConfiguration/Dot1XConfiguration/EAPMethodConfiguration/Extension' => 'ONVIF::Device::Types::EapMethodExtension',
               'RemoveIPAddressFilter/IPAddressFilter/IPv6Address/Address' => 'ONVIF::Device::Types::IPv6Address',
               'SetDot1XConfiguration/Dot1XConfiguration/Identity' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetUsersResponse/User/Extension' => 'ONVIF::Device::Types::UserExtension',
               'SetScopesResponse' => 'ONVIF::Device::Elements::SetScopesResponse',
               'GetServicesResponse' => 'ONVIF::Device::Elements::GetServicesResponse',
               'AddIPAddressFilter/IPAddressFilter/IPv4Address/PrefixLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetSystemLogResponse/SystemLog' => 'ONVIF::Device::Types::SystemLog',
               'GetDot1XConfigurationResponse/Dot1XConfiguration/EAPMethodConfiguration' => 'ONVIF::Device::Types::EAPMethodConfiguration',
               'GetCapabilitiesResponse/Capabilities/Media' => 'ONVIF::Device::Types::MediaCapabilities',
               'GetCapabilitiesResponse/Capabilities/Extension/Receiver/RTP_TCP' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetSystemLogResponse/SystemLog/String' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetCapabilitiesResponse/Capabilities/Extension/AnalyticsDevice/RuleSupport' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetIPAddressFilter/IPAddressFilter/IPv6Address/PrefixLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetDeviceInformationResponse' => 'ONVIF::Device::Elements::GetDeviceInformationResponse',
               'CreateDot1XConfiguration/Dot1XConfiguration/Dot1XConfigurationToken' => 'ONVIF::Device::Types::ReferenceToken',
               'CreateDot1XConfiguration/Dot1XConfiguration/EAPMethodConfiguration/TLSConfiguration' => 'ONVIF::Device::Types::TLSConfiguration',
               'GetCapabilitiesResponse/Capabilities/Extension/AnalyticsDevice/XAddr' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetDot11StatusResponse/Status/BSSID' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'SetNetworkDefaultGateway/IPv4Address' => 'ONVIF::Device::Types::IPv4Address',
               'GetDynamicDNSResponse/DynamicDNSInformation/Type' => 'ONVIF::Device::Types::DynamicDNSType',
               'GetHostnameResponse/HostnameInformation/FromDHCP' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetCapabilitiesResponse/Capabilities/Imaging' => 'ONVIF::Device::Types::ImagingCapabilities',
               'SetSystemDateAndTime/DateTimeType' => 'ONVIF::Device::Types::SetDateTimeType',
               'DeleteDot1XConfiguration/Dot1XConfigurationToken' => 'ONVIF::Device::Types::ReferenceToken',
               'SetNetworkInterfaces/NetworkInterface/Link/AutoNegotiation' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/LocalDateTime/Time/Minute' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/DaylightSavings' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'ScanAvailableDot11NetworksResponse/Networks' => 'ONVIF::Device::Types::Dot11AvailableNetworks',
               'GetCapabilitiesResponse/Capabilities/Device/System/SupportedVersions' => 'ONVIF::Device::Types::OnvifVersion',
               'StartFirmwareUpgradeResponse/UploadDelay' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'CreateCertificate/Subject' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetCapabilitiesResponse/Capabilities/Device/Network/Extension' => 'ONVIF::Device::Types::NetworkCapabilitiesExtension',
               'RemoveScopesResponse/ScopeItem' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetCapabilitiesResponse/Capabilities/Extension/AnalyticsDevice/Extension' => 'ONVIF::Device::Types::AnalyticsDeviceExtension',
               'GetCertificateInformationResponse/CertificateInformation/Validity' => 'ONVIF::Device::Types::DateTimeRange',
               'GetDNSResponse/DNSInformation/DNSFromDHCP/Type' => 'ONVIF::Device::Types::IPType',
               'GetCapabilitiesResponse/Capabilities/Device/Security/Extension/Extension/RemoteUserHandling' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetNetworkDefaultGatewayResponse/NetworkGateway/IPv6Address' => 'ONVIF::Device::Types::IPv6Address',
               'GetCACertificatesResponse' => 'ONVIF::Device::Elements::GetCACertificatesResponse',
               'ScanAvailableDot11NetworksResponse/Networks/PairCipher' => 'ONVIF::Device::Types::Dot11Cipher',
               'SetNetworkDefaultGateway' => 'ONVIF::Device::Elements::SetNetworkDefaultGateway',
               'SetNetworkInterfaces/NetworkInterface/IPv4/Manual' => 'ONVIF::Device::Types::PrefixedIPv4Address',
               'ScanAvailableDot11NetworksResponse/Networks/SignalStrength' => 'ONVIF::Device::Types::Dot11SignalStrength',
               'SetAccessPolicyResponse' => 'ONVIF::Device::Elements::SetAccessPolicyResponse',
               'GetDeviceInformationResponse/Manufacturer' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'RemoveIPAddressFilter/IPAddressFilter/IPv4Address/Address' => 'ONVIF::Device::Types::IPv4Address',
               'GetDot11StatusResponse/Status/PairCipher' => 'ONVIF::Device::Types::Dot11Cipher',
               'GetDNSResponse/DNSInformation/DNSManual/Type' => 'ONVIF::Device::Types::IPType',
               'GetCapabilitiesResponse/Capabilities/Device/System/Extension/HttpSystemLogging' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'LoadCertificateWithPrivateKey/CertificateWithPrivateKey/Certificate/Data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'SetDynamicDNS/TTL' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetCapabilitiesResponse/Capabilities/Device/Security' => 'ONVIF::Device::Types::SecurityCapabilities',
               'SetSystemDateAndTime' => 'ONVIF::Device::Elements::SetSystemDateAndTime',
               'GetIPAddressFilterResponse' => 'ONVIF::Device::Elements::GetIPAddressFilterResponse',
               'SystemRebootResponse/Message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetNTPResponse/NTPInformation/FromDHCP' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetNetworkInterfaces/NetworkInterface/IPv6/DHCP' => 'ONVIF::Device::Types::IPv6DHCPConfiguration',
               'GetNTPResponse/NTPInformation/Extension' => 'ONVIF::Device::Types::NTPInformationExtension',
               'GetSystemBackupResponse' => 'ONVIF::Device::Elements::GetSystemBackupResponse',
               'GetSystemBackupResponse/BackupFiles' => 'ONVIF::Device::Types::BackupFile',
               'StartSystemRestore' => 'ONVIF::Device::Elements::StartSystemRestore',
               'GetNetworkProtocolsResponse/NetworkProtocols/Port' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetCertificateInformationResponse/CertificateInformation/Validity/From' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Extension/Dot11/Security/PSK/Key' => 'ONVIF::Device::Types::Dot11PSK',
               'GetScopesResponse/Scopes/ScopeDef' => 'ONVIF::Device::Types::ScopeDefinition',
               'SetNetworkInterfaces/NetworkInterface/Extension/Dot11/Priority' => 'ONVIF::Device::Types::NetworkInterfaceConfigPriority',
               'CreateDot1XConfiguration/Dot1XConfiguration/EAPMethodConfiguration/TLSConfiguration/CertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'GetAccessPolicyResponse/PolicyFile/Data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'SetNTP/NTPManual/DNSname' => 'ONVIF::Device::Types::DNSName',
               'GetServicesResponse/Service/XAddr' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetCapabilitiesResponse' => 'ONVIF::Device::Elements::GetCapabilitiesResponse',
               'GetDNSResponse/DNSInformation/DNSManual/IPv6Address' => 'ONVIF::Device::Types::IPv6Address',
               'GetClientCertificateModeResponse' => 'ONVIF::Device::Elements::GetClientCertificateModeResponse',
               'GetSystemBackup' => 'ONVIF::Device::Elements::GetSystemBackup',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv4/Config/Manual/Address' => 'ONVIF::Device::Types::IPv4Address',
               'SetUser/User/Username' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'LoadCertificatesResponse' => 'ONVIF::Device::Elements::LoadCertificatesResponse',
               'SetDPAddresses/DPAddress/Type' => 'ONVIF::Device::Types::NetworkHostType',
               'GetRelayOutputsResponse' => 'ONVIF::Device::Elements::GetRelayOutputsResponse',
               'GetDNSResponse/DNSInformation/DNSFromDHCP' => 'ONVIF::Device::Types::IPAddress',
               'GetRelayOutputsResponse/RelayOutputs/Properties' => 'ONVIF::Device::Types::RelayOutputSettings',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/LocalDateTime' => 'ONVIF::Device::Types::DateTime',
               'GetSystemDateAndTime' => 'ONVIF::Device::Elements::GetSystemDateAndTime',
               'GetNTP' => 'ONVIF::Device::Elements::GetNTP',
               'UpgradeSystemFirmware/Firmware/Include' => 'ONVIF::Device::Types::Include',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv6/Enabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetDeviceInformationResponse/SerialNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetDPAddresses' => 'ONVIF::Device::Elements::GetDPAddresses',
               'SetRemoteUser/RemoteUser/UseDerivedPassword' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetPkcs10Request/CertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'SystemReboot' => 'ONVIF::Device::Elements::SystemReboot',
               'SetNTP/NTPManual/IPv4Address' => 'ONVIF::Device::Types::IPv4Address',
               'RemoveIPAddressFilter/IPAddressFilter/Extension' => 'ONVIF::Device::Types::IPAddressFilterExtension',
               'GetCapabilitiesResponse/Capabilities/Events/WSPullPointSupport' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv6/Config/LinkLocal/PrefixLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetDot1XConfiguration/Dot1XConfiguration/CACertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'DeleteCertificates/CertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'LoadCACertificates/CACertificate/CertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'GetCertificatesResponse' => 'ONVIF::Device::Elements::GetCertificatesResponse',
               'GetSystemLogResponse' => 'ONVIF::Device::Elements::GetSystemLogResponse',
               'GetCertificateInformationResponse/CertificateInformation/CertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'GetNTPResponse/NTPInformation/NTPManual/Type' => 'ONVIF::Device::Types::NetworkHostType',
               'GetRelayOutputs' => 'ONVIF::Device::Elements::GetRelayOutputs',
               'GetDot1XConfigurationsResponse/Dot1XConfiguration/Dot1XConfigurationToken' => 'ONVIF::Device::Types::ReferenceToken',
               'GetDot11StatusResponse' => 'ONVIF::Device::Elements::GetDot11StatusResponse',
               'GetDeviceInformationResponse/FirmwareVersion' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'SetDPAddresses/DPAddress/DNSname' => 'ONVIF::Device::Types::DNSName',
               'LoadCertificates/NVTCertificate/Certificate/Data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'GetCertificateInformationResponse/CertificateInformation/ExtendedKeyUsage' => 'ONVIF::Device::Types::CertificateUsage',
               'RemoveIPAddressFilter' => 'ONVIF::Device::Elements::RemoveIPAddressFilter',
               'GetDiscoveryMode' => 'ONVIF::Device::Elements::GetDiscoveryMode',
               'GetCapabilitiesResponse/Capabilities/Extension/Recording/MaxStringLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetNetworkInterfacesResponse' => 'ONVIF::Device::Elements::SetNetworkInterfacesResponse',
               'GetCertificatesResponse/NvtCertificate/Certificate' => 'ONVIF::Device::Types::BinaryData',
               'GetCapabilitiesResponse/Capabilities/Device/System/RemoteDiscovery' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetNetworkProtocolsResponse/NetworkProtocols/Extension' => 'ONVIF::Device::Types::NetworkProtocolExtension',
               'GetNetworkProtocolsResponse' => 'ONVIF::Device::Elements::GetNetworkProtocolsResponse',
               'GetServiceCapabilitiesResponse/Capabilities/Security' => 'ONVIF::Device::Types::SecurityCapabilities',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Info' => 'ONVIF::Device::Types::NetworkInterfaceInfo',
               'CreateDot1XConfiguration/Dot1XConfiguration/AnonymousID' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetDot1XConfigurationResponse/Dot1XConfiguration/Identity' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetNTPResponse/NTPInformation/NTPManual/IPv4Address' => 'ONVIF::Device::Types::IPv4Address',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Extension/Dot11/Priority' => 'ONVIF::Device::Types::NetworkInterfaceConfigPriority',
               'GetSystemUrisResponse/SupportInfoUri' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'SetSystemFactoryDefaultResponse' => 'ONVIF::Device::Elements::SetSystemFactoryDefaultResponse',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv6/Config/FromRA' => 'ONVIF::Device::Types::PrefixedIPv6Address',
               'GetCapabilitiesResponse/Capabilities/Media/XAddr' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetServicesResponse/Service/Version/Major' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Link/AdminSettings/Speed' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetCapabilitiesResponse/Capabilities/Extension/Receiver/SupportedReceivers' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CreateCertificate/CertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'GetSystemSupportInformationResponse/SupportInformation/Binary/Include' => 'ONVIF::Device::Types::Include',
               'GetRemoteDiscoveryMode' => 'ONVIF::Device::Elements::GetRemoteDiscoveryMode',
               'GetUsersResponse/User/Username' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetCapabilitiesResponse/Capabilities/Device/System' => 'ONVIF::Device::Types::SystemCapabilities',
               'GetPkcs10RequestResponse/Pkcs10Request/Data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'GetWsdlUrlResponse/WsdlUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'CreateDot1XConfiguration/Dot1XConfiguration/Identity' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetDiscoveryModeResponse/DiscoveryMode' => 'ONVIF::Device::Types::DiscoveryMode',
               'GetCACertificatesResponse/CACertificate/CertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'SetRemoteUser/RemoteUser' => 'ONVIF::Device::Types::RemoteUser',
               'SetIPAddressFilter/IPAddressFilter' => 'ONVIF::Device::Types::IPAddressFilter',
               'SetSystemDateAndTime/UTCDateTime' => 'ONVIF::Device::Types::DateTime',
               'GetCapabilitiesResponse/Capabilities/Analytics/XAddr' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'SetCertificatesStatusResponse' => 'ONVIF::Device::Elements::SetCertificatesStatusResponse',
               'GetCapabilitiesResponse/Capabilities/Device/Network/ZeroConfiguration' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetRemoteDiscoveryMode' => 'ONVIF::Device::Elements::SetRemoteDiscoveryMode',
               'GetCapabilitiesResponse/Capabilities/Events/WSSubscriptionPolicySupport' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetDPAddressesResponse' => 'ONVIF::Device::Elements::SetDPAddressesResponse',
               'SetNetworkDefaultGatewayResponse' => 'ONVIF::Device::Elements::SetNetworkDefaultGatewayResponse',
               'RestoreSystem/BackupFiles' => 'ONVIF::Device::Types::BackupFile',
               'LoadCertificateWithPrivateKey/CertificateWithPrivateKey/Certificate' => 'ONVIF::Device::Types::BinaryData',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Info/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'SetDNS/DNSManual' => 'ONVIF::Device::Types::IPAddress',
               'SetNetworkInterfaces/NetworkInterface/Extension/Dot11/Security/Extension' => 'ONVIF::Device::Types::Dot11SecurityConfigurationExtension',
               'GetCapabilitiesResponse/Capabilities/Device/Security/TLS1.1' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetSystemLog/LogType' => 'ONVIF::Device::Types::SystemLogType',
               'AddIPAddressFilter/IPAddressFilter/IPv6Address' => 'ONVIF::Device::Types::PrefixedIPv6Address',
               'GetDynamicDNSResponse' => 'ONVIF::Device::Elements::GetDynamicDNSResponse',
               'SetNetworkInterfaces/NetworkInterface/Extension/Dot11/SSID' => 'ONVIF::Device::Types::Dot11SSIDType',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/Extension' => 'ONVIF::Device::Types::SystemDateTimeExtension',
               'GetDot11StatusResponse/Status' => 'ONVIF::Device::Types::Dot11Status',
               'RemoveIPAddressFilter/IPAddressFilter/IPv4Address' => 'ONVIF::Device::Types::PrefixedIPv4Address',
               'SetDynamicDNS/Type' => 'ONVIF::Device::Types::DynamicDNSType',
               'GetDeviceInformation' => 'ONVIF::Device::Elements::GetDeviceInformation',
               'GetDot1XConfiguration' => 'ONVIF::Device::Elements::GetDot1XConfiguration',
               'GetCapabilitiesResponse/Capabilities/Extension/DeviceIO/RelayOutputs' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetDot1XConfiguration/Dot1XConfiguration' => 'ONVIF::Device::Types::Dot1XConfiguration',
               'GetUsersResponse' => 'ONVIF::Device::Elements::GetUsersResponse',
               'SetDynamicDNS/Name' => 'ONVIF::Device::Types::DNSName',
               'GetCapabilitiesResponse/Capabilities/Extension/Receiver/MaximumRTSPURILength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetSystemUris' => 'ONVIF::Device::Elements::GetSystemUris',
               'DeleteDot1XConfiguration' => 'ONVIF::Device::Elements::DeleteDot1XConfiguration',
               'SetDNS/DNSManual/Type' => 'ONVIF::Device::Types::IPType',
               'GetDot11CapabilitiesResponse/Capabilities/AdHocStationMode' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Extension/Extension' => 'ONVIF::Device::Types::NetworkInterfaceExtension2',
               'GetDot1XConfigurationResponse/Dot1XConfiguration/CACertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'GetCapabilitiesResponse/Capabilities/Extension/DeviceIO/VideoOutputs' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetDynamicDNSResponse/DynamicDNSInformation/Extension' => 'ONVIF::Device::Types::DynamicDNSInformationExtension',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv4/Config/FromDHCP/PrefixLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/LocalDateTime/Time' => 'ONVIF::Device::Types::Time',
               'GetZeroConfigurationResponse/ZeroConfiguration/Addresses' => 'ONVIF::Device::Types::IPv4Address',
               'SendAuxiliaryCommand/AuxiliaryCommand' => 'ONVIF::Device::Types::AuxiliaryData',
               'GetCapabilitiesResponse/Capabilities/Device/IO/Extension/AuxiliaryCommands' => 'ONVIF::Device::Types::AuxiliaryData',
               'GetZeroConfigurationResponse' => 'ONVIF::Device::Elements::GetZeroConfigurationResponse',
               'GetCapabilitiesResponse/Capabilities/Device/System/FirmwareUpgrade' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetHostnameResponse' => 'ONVIF::Device::Elements::GetHostnameResponse',
               'RestoreSystem' => 'ONVIF::Device::Elements::RestoreSystem',
               'GetCapabilitiesResponse/Capabilities/Device/IO/Extension/Extension' => 'ONVIF::Device::Types::IOCapabilitiesExtension2',
               'SetIPAddressFilter/IPAddressFilter/IPv4Address/Address' => 'ONVIF::Device::Types::IPv4Address',
               'GetCapabilitiesResponse/Capabilities/Media/Extension/ProfileCapabilities' => 'ONVIF::Device::Types::ProfileCapabilities',
               'SetNetworkInterfaces/NetworkInterface/IPv4/Manual/PrefixLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Extension/Dot11/Security/Mode' => 'ONVIF::Device::Types::Dot11SecurityMode',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv4' => 'ONVIF::Device::Types::IPv4NetworkInterface',
               'RestoreSystem/BackupFiles/Data/Include' => 'ONVIF::Device::Types::Include',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv6/Config/Manual' => 'ONVIF::Device::Types::PrefixedIPv6Address',
               'GetZeroConfigurationResponse/ZeroConfiguration/InterfaceToken' => 'ONVIF::Device::Types::ReferenceToken',
               'GetHostnameResponse/HostnameInformation/Extension' => 'ONVIF::Device::Types::HostnameInformationExtension',
               'GetCapabilitiesResponse/Capabilities/Device/Security/TLS1.2' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetUsersResponse/User' => 'ONVIF::Device::Types::User',
               'GetCapabilitiesResponse/Capabilities/Media/Extension' => 'ONVIF::Device::Types::MediaCapabilitiesExtension',
               'GetCapabilitiesResponse/Capabilities/Device/System/SupportedVersions/Minor' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetZeroConfigurationResponse' => 'ONVIF::Device::Elements::SetZeroConfigurationResponse',
               'GetCapabilitiesResponse/Capabilities/Extension/Search/XAddr' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetServiceCapabilities' => 'ONVIF::Device::Elements::GetServiceCapabilities',
               'GetSystemLog' => 'ONVIF::Device::Elements::GetSystemLog',
               'GetCACertificates' => 'ONVIF::Device::Elements::GetCACertificates',
               'GetDNSResponse/DNSInformation/DNSFromDHCP/IPv6Address' => 'ONVIF::Device::Types::IPv6Address',
               'SetDNS/DNSManual/IPv6Address' => 'ONVIF::Device::Types::IPv6Address',
               'SetNetworkInterfaces/NetworkInterface/Extension/Dot3' => 'ONVIF::Device::Types::Dot3Configuration',
               'SetUser/User/Password' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'SetNTP/NTPManual/Type' => 'ONVIF::Device::Types::NetworkHostType',
               'LoadCertificateWithPrivateKey' => 'ONVIF::Device::Elements::LoadCertificateWithPrivateKey',
               'GetNetworkDefaultGateway' => 'ONVIF::Device::Elements::GetNetworkDefaultGateway',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Link/InterfaceType' => 'ONVIF::Device::Types::IANA_IfTypes',
               'GetCapabilitiesResponse/Capabilities/Device/IO/RelayOutputs' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/DateTimeType' => 'ONVIF::Device::Types::SetDateTimeType',
               'CreateUsers' => 'ONVIF::Device::Elements::CreateUsers',
               'AddIPAddressFilter/IPAddressFilter/IPv4Address/Address' => 'ONVIF::Device::Types::IPv4Address',
               'GetDynamicDNSResponse/DynamicDNSInformation/TTL' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetCapabilitiesResponse/Capabilities/Device/Security/OnboardKeyGeneration' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetPkcs10RequestResponse' => 'ONVIF::Device::Elements::GetPkcs10RequestResponse',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv4/Config/LinkLocal/PrefixLength' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetNetworkInterfaces/NetworkInterface/Extension/Dot11/Security/PSK/Extension' => 'ONVIF::Device::Types::Dot11PSKSetExtension',
               'AddScopes' => 'ONVIF::Device::Elements::AddScopes',
               'SetDNS' => 'ONVIF::Device::Elements::SetDNS',
               'GetCertificateInformationResponse/CertificateInformation/Validity/Until' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Extension/Dot11' => 'ONVIF::Device::Types::Dot11Configuration',
               'GetSystemSupportInformationResponse/SupportInformation/Binary' => 'ONVIF::Device::Types::AttachmentData',
               'AddIPAddressFilter/IPAddressFilter' => 'ONVIF::Device::Types::IPAddressFilter',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv6/Config' => 'ONVIF::Device::Types::IPv6Configuration',
               'GetSystemBackupResponse/BackupFiles/Data' => 'ONVIF::Device::Types::AttachmentData',
               'GetNetworkInterfacesResponse/NetworkInterfaces/Extension' => 'ONVIF::Device::Types::NetworkInterfaceExtension',
               'GetCapabilitiesResponse/Capabilities/PTZ' => 'ONVIF::Device::Types::PTZCapabilities',
               'SetNetworkProtocols/NetworkProtocols/Port' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetNTPResponse/NTPInformation/NTPFromDHCP/Extension' => 'ONVIF::Device::Types::NetworkHostExtension',
               'GetNetworkInterfacesResponse/NetworkInterfaces/IPv4/Config/DHCP' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetNetworkInterfacesResponse' => 'ONVIF::Device::Elements::GetNetworkInterfacesResponse',
               'GetSystemDateAndTimeResponse/SystemDateAndTime/UTCDateTime/Time/Second' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetDiscoveryModeResponse' => 'ONVIF::Device::Elements::SetDiscoveryModeResponse',
               'SetNetworkProtocols/NetworkProtocols/Extension' => 'ONVIF::Device::Types::NetworkProtocolExtension',
               'SetDynamicDNS' => 'ONVIF::Device::Elements::SetDynamicDNS',
               'SetSystemDateAndTime/DaylightSavings' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'CreateDot1XConfiguration/Dot1XConfiguration/CACertificateID' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'GetCertificatesResponse/NvtCertificate/Certificate/Data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

ONVIF::Device::Typemaps::Device - typemap for Device

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

