
package ONVIF::Analytics::Elements::VideoSourceConfiguration;
use strict;
use warnings;

{ # BLOCK to scope variables

sub get_xmlns { 'http://www.onvif.org/ver10/schema' }

__PACKAGE__->__set_name('VideoSourceConfiguration');
__PACKAGE__->__set_nillable();
__PACKAGE__->__set_minOccurs();
__PACKAGE__->__set_maxOccurs();
__PACKAGE__->__set_ref();
use base qw(
    SOAP::WSDL::XSD::Typelib::Element
    ONVIF::Analytics::Types::VideoSourceConfiguration
);

}

1;


=pod

=head1 NAME

ONVIF::Analytics::Elements::VideoSourceConfiguration

=head1 DESCRIPTION

Perl data type class for the XML Schema defined element
VideoSourceConfiguration from the namespace http://www.onvif.org/ver10/schema.







=head1 METHODS

=head2 new

 my $element = ONVIF::Analytics::Elements::VideoSourceConfiguration->new($data);

Constructor. The following data structure may be passed to new():

 { # ONVIF::Analytics::Types::VideoSourceConfiguration
   SourceToken => $some_value, # ReferenceToken
   Bounds => ,
   Extension =>  { # ONVIF::Analytics::Types::VideoSourceConfigurationExtension
     Rotate =>  { # ONVIF::Analytics::Types::Rotate
       Mode => $some_value, # RotateMode
       Degree =>  $some_value, # int
       Extension =>  { # ONVIF::Analytics::Types::RotateExtension
       },
     },
     Extension =>  { # ONVIF::Analytics::Types::VideoSourceConfigurationExtension2
     },
   },
 },

=head1 AUTHOR

Generated by SOAP::WSDL

=cut

