tr.log-fat td {
    background-color:#ffcccc;
    font-weight: bold;
}

tr.log-err td {
    background-color:#ffcccc;
}

tr.log-war td {
    background-color: #ffe4b5;
}

tr.log-dbg td {
    color: #666666;
    font-style: italic;
}

th[data-field="DateTime"],
th[data-field="Component"],
th[data-field="Code"],
th[data-field="Message"],
th[data-field="File"],
th[data-field="Server"],
th[data-field="Line"] {
  text-align: left;
}
th[data-field="DateTime"] {
  min-width: 135px;
}
.search .form-control {
    font-size: 100%;
}
