.bootstrap-table .table > tbody > tr.group-by.expanded,
.bootstrap-table .table > tbody > tr.group-by.collapsed {
  cursor: pointer;
}

.bootstrap-table .table > tbody > tr.hidden {
  display: none;
}
