input {
    margin-top: 6px;
}

#contentTable th, #contentTable td {
    white-space: nowrap;
}

#exportProgress {
    margin: 8px auto 4px;
}

#downloadLink {
    margin-top: 8px;
}

.export_options .form-group {
  text-align: right;
}
