function submitCamera( element ) {
  var form = element.form;
  form.target = self.name;
  form.view.value = 'monitor';
  form.submit();
}

function gotoStep1( element ) {
  var form = element.form;
  form.target = self.name;
  form.view.value = 'onvifprobe';
  form.step.value = '1';
  form.submit();
}

function gotoStep2( element ) {
  var form = element.form;
  form.target = self.name;
  form.view.value = 'onvifprobe';
  form.step.value = '2';
  form.submit();
}

function configureButtons(element) {
  var form = element.form;
  if (form.elements.namedItem('nextBtn')) {
    form.nextBtn.disabled = (form.probe.selectedIndex==0) ||
      (form.Username == '') || (form.Username == null) ||
      (form.Password == '') || (form.Password == null);
  }
  if (form.elements.namedItem('saveBtn')) {
    form.saveBtn.disabled = (form.probe.selectedIndex==0);
  }
}

function changeInterface(element) {
  gotoStep1(element);
}
