
package ONVIF::PTZ::Elements::SendAuxiliaryCommand;
use strict;
use warnings;

{ # BLOCK to scope variables

sub get_xmlns { 'http://www.onvif.org/ver20/ptz/wsdl' }

__PACKAGE__->__set_name('SendAuxiliaryCommand');
__PACKAGE__->__set_nillable();
__PACKAGE__->__set_minOccurs();
__PACKAGE__->__set_maxOccurs();
__PACKAGE__->__set_ref();

use base qw(
    SOAP::WSDL::XSD::Typelib::Element
    SOAP::WSDL::XSD::Typelib::ComplexType
);

our $XML_ATTRIBUTE_CLASS;
undef $XML_ATTRIBUTE_CLASS;

sub __get_attr_class {
    return $XML_ATTRIBUTE_CLASS;
}

use Class::Std::Fast::Storable constructor => 'none';
use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

Class::Std::initialize();

{ # BLOCK to scope variables

my %ProfileToken_of :ATTR(:get<ProfileToken>);
my %AuxiliaryData_of :ATTR(:get<AuxiliaryData>);

__PACKAGE__->_factory(
    [ qw(        ProfileToken
        AuxiliaryData

    ) ],
    {
        'ProfileToken' => \%ProfileToken_of,
        'AuxiliaryData' => \%AuxiliaryData_of,
    },
    {
        'ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
        'AuxiliaryData' => 'ONVIF::PTZ::Types::AuxiliaryData',
    },
    {

        'ProfileToken' => 'ProfileToken',
        'AuxiliaryData' => 'AuxiliaryData',
    }
);

} # end BLOCK







} # end of BLOCK



1;


=pod

=head1 NAME

ONVIF::PTZ::Elements::SendAuxiliaryCommand

=head1 DESCRIPTION

Perl data type class for the XML Schema defined element
SendAuxiliaryCommand from the namespace http://www.onvif.org/ver20/ptz/wsdl.







=head1 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

=over

=item * ProfileToken

 $element->set_ProfileToken($data);
 $element->get_ProfileToken();




=item * AuxiliaryData

 $element->set_AuxiliaryData($data);
 $element->get_AuxiliaryData();





=back


=head1 METHODS

=head2 new

 my $element = ONVIF::PTZ::Elements::SendAuxiliaryCommand->new($data);

Constructor. The following data structure may be passed to new():

 {
   ProfileToken => $some_value, # ReferenceToken
   AuxiliaryData => $some_value, # AuxiliaryData
 },

=head1 AUTHOR

Generated by SOAP::WSDL

=cut

