
package ONVIF::Analytics::Elements::GetSupportedAnalyticsModulesResponse;
use strict;
use warnings;

{ # BLOCK to scope variables

sub get_xmlns { 'http://www.onvif.org/ver20/analytics/wsdl' }

__PACKAGE__->__set_name('GetSupportedAnalyticsModulesResponse');
__PACKAGE__->__set_nillable();
__PACKAGE__->__set_minOccurs();
__PACKAGE__->__set_maxOccurs();
__PACKAGE__->__set_ref();

use base qw(
    SOAP::WSDL::XSD::Typelib::Element
    SOAP::WSDL::XSD::Typelib::ComplexType
);

our $XML_ATTRIBUTE_CLASS;
undef $XML_ATTRIBUTE_CLASS;

sub __get_attr_class {
    return $XML_ATTRIBUTE_CLASS;
}

use Class::Std::Fast::Storable constructor => 'none';
use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

Class::Std::initialize();

{ # BLOCK to scope variables

my %SupportedAnalyticsModules_of :ATTR(:get<SupportedAnalyticsModules>);

__PACKAGE__->_factory(
    [ qw(        SupportedAnalyticsModules

    ) ],
    {
        'SupportedAnalyticsModules' => \%SupportedAnalyticsModules_of,
    },
    {
        'SupportedAnalyticsModules' => 'ONVIF::Analytics::Types::SupportedAnalyticsModules',
    },
    {

        'SupportedAnalyticsModules' => 'SupportedAnalyticsModules',
    }
);

} # end BLOCK







} # end of BLOCK



1;


=pod

=head1 NAME

ONVIF::Analytics::Elements::GetSupportedAnalyticsModulesResponse

=head1 DESCRIPTION

Perl data type class for the XML Schema defined element
GetSupportedAnalyticsModulesResponse from the namespace http://www.onvif.org/ver20/analytics/wsdl.







=head1 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

=over

=item * SupportedAnalyticsModules

 $element->set_SupportedAnalyticsModules($data);
 $element->get_SupportedAnalyticsModules();





=back


=head1 METHODS

=head2 new

 my $element = ONVIF::Analytics::Elements::GetSupportedAnalyticsModulesResponse->new($data);

Constructor. The following data structure may be passed to new():

 {
   SupportedAnalyticsModules =>  { # ONVIF::Analytics::Types::SupportedAnalyticsModules
     AnalyticsModuleContentSchemaLocation =>  $some_value, # anyURI
     AnalyticsModuleDescription =>  { # ONVIF::Analytics::Types::ConfigDescription
       Parameters =>  { # ONVIF::Analytics::Types::ItemListDescription
         SimpleItemDescription => ,
         ElementItemDescription => ,
         Extension =>  { # ONVIF::Analytics::Types::ItemListDescriptionExtension
         },
       },
       Messages =>  {
         ParentTopic =>  $some_value, # string
       },
       Extension =>  { # ONVIF::Analytics::Types::ConfigDescriptionExtension
       },
     },
     Extension =>  { # ONVIF::Analytics::Types::SupportedAnalyticsModulesExtension
     },
   },
 },

=head1 AUTHOR

Generated by SOAP::WSDL

=cut

