/**
 * @author vincent loh <vincent.ml@gmail.com>
 * @update zhixin wen <wenzhixin2010@gmail.com>
 */
.fix-sticky {
  position: fixed !important;
  overflow: hidden;
  z-index: 100;
}

.fix-sticky table thead {
  background: #fff;
}

.fix-sticky table thead.thead-light {
  background: #e9ecef;
}

.fix-sticky table thead.thead-dark {
  background: #212529;
}
