package ONVIF::PTZ::Types::Exposure20;
use strict;
use warnings;


__PACKAGE__->_set_element_form_qualified(1);

sub get_xmlns { 'http://www.onvif.org/ver10/schema' };

our $XML_ATTRIBUTE_CLASS;
undef $XML_ATTRIBUTE_CLASS;

sub __get_attr_class {
    return $XML_ATTRIBUTE_CLASS;
}

use Class::Std::Fast::Storable constructor => 'none';
use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

Class::Std::initialize();

{ # BLOCK to scope variables

my %Mode_of :ATTR(:get<Mode>);
my %Priority_of :ATTR(:get<Priority>);
my %Window_of :ATTR(:get<Window>);
my %MinExposureTime_of :ATTR(:get<MinExposureTime>);
my %MaxExposureTime_of :ATTR(:get<MaxExposureTime>);
my %MinGain_of :ATTR(:get<MinGain>);
my %MaxGain_of :ATTR(:get<MaxGain>);
my %MinIris_of :ATTR(:get<MinIris>);
my %MaxIris_of :ATTR(:get<MaxIris>);
my %ExposureTime_of :ATTR(:get<ExposureTime>);
my %Gain_of :ATTR(:get<Gain>);
my %Iris_of :ATTR(:get<Iris>);

__PACKAGE__->_factory(
    [ qw(        Mode
        Priority
        Window
        MinExposureTime
        MaxExposureTime
        MinGain
        MaxGain
        MinIris
        MaxIris
        ExposureTime
        Gain
        Iris

    ) ],
    {
        'Mode' => \%Mode_of,
        'Priority' => \%Priority_of,
        'Window' => \%Window_of,
        'MinExposureTime' => \%MinExposureTime_of,
        'MaxExposureTime' => \%MaxExposureTime_of,
        'MinGain' => \%MinGain_of,
        'MaxGain' => \%MaxGain_of,
        'MinIris' => \%MinIris_of,
        'MaxIris' => \%MaxIris_of,
        'ExposureTime' => \%ExposureTime_of,
        'Gain' => \%Gain_of,
        'Iris' => \%Iris_of,
    },
    {
        'Mode' => 'ONVIF::PTZ::Types::ExposureMode',
        'Priority' => 'ONVIF::PTZ::Types::ExposurePriority',
        'Window' => 'ONVIF::PTZ::Types::Rectangle',
        'MinExposureTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
        'MaxExposureTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
        'MinGain' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
        'MaxGain' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
        'MinIris' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
        'MaxIris' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
        'ExposureTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
        'Gain' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
        'Iris' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
    },
    {

        'Mode' => 'Mode',
        'Priority' => 'Priority',
        'Window' => 'Window',
        'MinExposureTime' => 'MinExposureTime',
        'MaxExposureTime' => 'MaxExposureTime',
        'MinGain' => 'MinGain',
        'MaxGain' => 'MaxGain',
        'MinIris' => 'MinIris',
        'MaxIris' => 'MaxIris',
        'ExposureTime' => 'ExposureTime',
        'Gain' => 'Gain',
        'Iris' => 'Iris',
    }
);

} # end BLOCK








1;


=pod

=head1 NAME

ONVIF::PTZ::Types::Exposure20

=head1 DESCRIPTION

Perl data type class for the XML Schema defined complexType
Exposure20 from the namespace http://www.onvif.org/ver10/schema.

Type describing the exposure settings.




=head2 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

=over

=item * Mode


=item * Priority


=item * Window


=item * MinExposureTime


=item * MaxExposureTime


=item * MinGain


=item * MaxGain


=item * MinIris


=item * MaxIris


=item * ExposureTime


=item * Gain


=item * Iris




=back


=head1 METHODS

=head2 new

Constructor. The following data structure may be passed to new():

 { # ONVIF::PTZ::Types::Exposure20
   Mode => $some_value, # ExposureMode
   Priority => $some_value, # ExposurePriority
   Window => ,
   MinExposureTime =>  $some_value, # float
   MaxExposureTime =>  $some_value, # float
   MinGain =>  $some_value, # float
   MaxGain =>  $some_value, # float
   MinIris =>  $some_value, # float
   MaxIris =>  $some_value, # float
   ExposureTime =>  $some_value, # float
   Gain =>  $some_value, # float
   Iris =>  $some_value, # float
 },




=head1 AUTHOR

Generated by SOAP::WSDL

=cut

