package ONVIF::Media::Types::IPv4NetworkInterfaceSetConfiguration;
use strict;
use warnings;


__PACKAGE__->_set_element_form_qualified(1);

sub get_xmlns { 'http://www.onvif.org/ver10/schema' };

our $XML_ATTRIBUTE_CLASS;
undef $XML_ATTRIBUTE_CLASS;

sub __get_attr_class {
    return $XML_ATTRIBUTE_CLASS;
}

use Class::Std::Fast::Storable constructor => 'none';
use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

Class::Std::initialize();

{ # BLOCK to scope variables

my %Enabled_of :ATTR(:get<Enabled>);
my %Manual_of :ATTR(:get<Manual>);
my %DHCP_of :ATTR(:get<DHCP>);

__PACKAGE__->_factory(
    [ qw(        Enabled
        Manual
        DHCP

    ) ],
    {
        'Enabled' => \%Enabled_of,
        'Manual' => \%Manual_of,
        'DHCP' => \%DHCP_of,
    },
    {
        'Enabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
        'Manual' => 'ONVIF::Media::Types::PrefixedIPv4Address',
        'DHCP' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
    },
    {

        'Enabled' => 'Enabled',
        'Manual' => 'Manual',
        'DHCP' => 'DHCP',
    }
);

} # end BLOCK








1;


=pod

=head1 NAME

ONVIF::Media::Types::IPv4NetworkInterfaceSetConfiguration

=head1 DESCRIPTION

Perl data type class for the XML Schema defined complexType
IPv4NetworkInterfaceSetConfiguration from the namespace http://www.onvif.org/ver10/schema.






=head2 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

=over

=item * Enabled


=item * Manual


=item * DHCP




=back


=head1 METHODS

=head2 new

Constructor. The following data structure may be passed to new():

 { # ONVIF::Media::Types::IPv4NetworkInterfaceSetConfiguration
   Enabled =>  $some_value, # boolean
   Manual =>  { # ONVIF::Media::Types::PrefixedIPv4Address
     Address => $some_value, # IPv4Address
     PrefixLength =>  $some_value, # int
   },
   DHCP =>  $some_value, # boolean
 },




=head1 AUTHOR

Generated by SOAP::WSDL

=cut

