
package WSDiscovery10::Elements::MetadataVersion;
use strict;
use warnings;

{ # BLOCK to scope variables

sub get_xmlns { 'http://schemas.xmlsoap.org/ws/2005/04/discovery' }

__PACKAGE__->__set_name('MetadataVersion');
__PACKAGE__->__set_nillable();
__PACKAGE__->__set_minOccurs();
__PACKAGE__->__set_maxOccurs();
__PACKAGE__->__set_ref();
use base qw(
    SOAP::WSDL::XSD::Typelib::Element
    SOAP::WSDL::XSD::Typelib::Builtin::unsignedInt
);

}

1;


=pod

=head1 NAME

WSDiscovery10::Elements::MetadataVersion

=head1 DESCRIPTION

Perl data type class for the XML Schema defined element
MetadataVersion from the namespace http://schemas.xmlsoap.org/ws/2005/04/discovery.







=head1 METHODS

=head2 new

 my $element = WSDiscovery10::Elements::MetadataVersion->new($data);

Constructor. The following data structure may be passed to new():

 $some_value, # unsignedInt

=head1 AUTHOR

Generated by SOAP::WSDL

=cut

