
package ONVIF::Media::Elements::GetGuaranteedNumberOfVideoEncoderInstancesResponse;
use strict;
use warnings;

{ # BLOCK to scope variables

sub get_xmlns { 'http://www.onvif.org/ver10/media/wsdl' }

__PACKAGE__->__set_name('GetGuaranteedNumberOfVideoEncoderInstancesResponse');
__PACKAGE__->__set_nillable();
__PACKAGE__->__set_minOccurs();
__PACKAGE__->__set_maxOccurs();
__PACKAGE__->__set_ref();

use base qw(
    SOAP::WSDL::XSD::Typelib::Element
    SOAP::WSDL::XSD::Typelib::ComplexType
);

our $XML_ATTRIBUTE_CLASS;
undef $XML_ATTRIBUTE_CLASS;

sub __get_attr_class {
    return $XML_ATTRIBUTE_CLASS;
}

use Class::Std::Fast::Storable constructor => 'none';
use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

Class::Std::initialize();

{ # BLOCK to scope variables

my %TotalNumber_of :ATTR(:get<TotalNumber>);
my %JPEG_of :ATTR(:get<JPEG>);
my %H264_of :ATTR(:get<H264>);
my %MPEG4_of :ATTR(:get<MPEG4>);

__PACKAGE__->_factory(
    [ qw(        TotalNumber
        JPEG
        H264
        MPEG4

    ) ],
    {
        'TotalNumber' => \%TotalNumber_of,
        'JPEG' => \%JPEG_of,
        'H264' => \%H264_of,
        'MPEG4' => \%MPEG4_of,
    },
    {
        'TotalNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
        'JPEG' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
        'H264' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
        'MPEG4' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
    },
    {

        'TotalNumber' => 'TotalNumber',
        'JPEG' => 'JPEG',
        'H264' => 'H264',
        'MPEG4' => 'MPEG4',
    }
);

} # end BLOCK







} # end of BLOCK



1;


=pod

=head1 NAME

ONVIF::Media::Elements::GetGuaranteedNumberOfVideoEncoderInstancesResponse

=head1 DESCRIPTION

Perl data type class for the XML Schema defined element
GetGuaranteedNumberOfVideoEncoderInstancesResponse from the namespace http://www.onvif.org/ver10/media/wsdl.







=head1 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

=over

=item * TotalNumber

 $element->set_TotalNumber($data);
 $element->get_TotalNumber();




=item * JPEG

 $element->set_JPEG($data);
 $element->get_JPEG();




=item * H264

 $element->set_H264($data);
 $element->get_H264();




=item * MPEG4

 $element->set_MPEG4($data);
 $element->get_MPEG4();





=back


=head1 METHODS

=head2 new

 my $element = ONVIF::Media::Elements::GetGuaranteedNumberOfVideoEncoderInstancesResponse->new($data);

Constructor. The following data structure may be passed to new():

 {
   TotalNumber =>  $some_value, # int
   JPEG =>  $some_value, # int
   H264 =>  $some_value, # int
   MPEG4 =>  $some_value, # int
 },

=head1 AUTHOR

Generated by SOAP::WSDL

=cut

