package ONVIF::Media::Types::RelatesToType;
use strict;
use warnings;


__PACKAGE__->_set_element_form_qualified(1);

sub get_xmlns { 'http://www.w3.org/2005/08/addressing' };

our $XML_ATTRIBUTE_CLASS = 'ONVIF::Media::Types::RelatesToType::_RelatesToType::XmlAttr';

sub __get_attr_class {
    return $XML_ATTRIBUTE_CLASS;
}

use base qw(
    SOAP::WSDL::XSD::Typelib::ComplexType
    SOAP::WSDL::XSD::Typelib::Builtin::anyURI
);

package ONVIF::Media::Types::RelatesToType::_RelatesToType::XmlAttr;
use base qw(SOAP::WSDL::XSD::Typelib::AttributeSet);

{ # BLOCK to scope variables

my %RelationshipType_of :ATTR(:get<RelationshipType>);

__PACKAGE__->_factory(
    [ qw(
        RelationshipType
    ) ],
    {

        RelationshipType => \%RelationshipType_of,
    },
    {
        RelationshipType => 'ONVIF::Media::Types::RelationshipTypeOpenEnum',
    }
);

} # end BLOCK



1;


=pod

=head1 NAME

ONVIF::Media::Types::RelatesToType

=head1 DESCRIPTION

Perl data type class for the XML Schema defined complexType
RelatesToType from the namespace http://www.w3.org/2005/08/addressing.






=head2 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

=over



=back


=head1 METHODS

=head2 new

Constructor. The following data structure may be passed to new():

 { value => $some_value },



=head2 attr

NOTE: Attribute documentation is experimental, and may be inaccurate.
See the correspondent WSDL/XML Schema if in question.

This class has additional attributes, accessibly via the C<attr()> method.

attr() returns an object of the class ONVIF::Media::Types::RelatesToType::_RelatesToType::XmlAttr.

The following attributes can be accessed on this object via the corresponding
get_/set_ methods:

=over

=item * RelationshipType



This attribute is of type L<ONVIF::Media::Types::RelationshipTypeOpenEnum|ONVIF::Media::Types::RelationshipTypeOpenEnum>.


=back




=head1 AUTHOR

Generated by SOAP::WSDL

=cut

