#monitors {
    width: 100%;
    margin: 0 auto;
    text-align: center;
}

#monitors .monitorFrame {
    padding: 1px;
    float: left;
    width: 24.5%;
}

#monitors .monitor {
    text-align: center;
}

#monitorFrame0, #monitorFrame4, #monitorFrame8, #monitorFrame12, #monitorFrame16, #monitorFrame20 {
    clear: both;
}

#monitor0, #monitor4, #monitor8, #monitor12, #monitor16, #monitor20 {
    float: right;
}

#monitorFrame1, #monitorFrame5, #monitorFrame9, #monitorFrame13, #monitorFrame17, #monitorFrame21 {
    text-align: center;
}

#monitor1, #monitor5, #monitor9, #monitor13, #monitor17, #monitor21 {
}

#monitorFrame2, #monitorFrame6, #monitorFrame10, #monitorFrame14, #monitorFrame18, #monitorFrame22 {
    text-align: center;
}

#monitor2, #monitor6, #monitor10, #monitor14, #monitor18, #monitor22 {
}

#monitorFrame3, #monitorFrame7, #monitorFrame11, #monitorFrame15, #monitorFrame19, #monitorFrame23 {
}

#monitor3, #monitor7, #monitor11, #monitor15, #monitor19, #monitor23 {
    float: left;
}
