.zones polygon {
	fill-opacity: 0.25;
	stroke-width: 2px;
}
.Active {
	stroke: #ff0000;
	fill: #ff0000;
}
.Inclusive {
	stroke: #FFA500;
	fill: #FFA500;
}
.Exclusive {
	stroke: #800080;
	fill: #800080;
}
.Preclusive {
	stroke: #0000FF;
	fill: #0000FF;
}
