
package ONVIF::PTZ::Elements::GetStatusResponse;
use strict;
use warnings;

{ # BLOCK to scope variables

sub get_xmlns { 'http://www.onvif.org/ver20/ptz/wsdl' }

__PACKAGE__->__set_name('GetStatusResponse');
__PACKAGE__->__set_nillable();
__PACKAGE__->__set_minOccurs();
__PACKAGE__->__set_maxOccurs();
__PACKAGE__->__set_ref();

use base qw(
    SOAP::WSDL::XSD::Typelib::Element
    SOAP::WSDL::XSD::Typelib::ComplexType
);

our $XML_ATTRIBUTE_CLASS;
undef $XML_ATTRIBUTE_CLASS;

sub __get_attr_class {
    return $XML_ATTRIBUTE_CLASS;
}

use Class::Std::Fast::Storable constructor => 'none';
use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

Class::Std::initialize();

{ # BLOCK to scope variables

my %PTZStatus_of :ATTR(:get<PTZStatus>);

__PACKAGE__->_factory(
    [ qw(        PTZStatus

    ) ],
    {
        'PTZStatus' => \%PTZStatus_of,
    },
    {
        'PTZStatus' => 'ONVIF::PTZ::Types::PTZStatus',
    },
    {

        'PTZStatus' => 'PTZStatus',
    }
);

} # end BLOCK







} # end of BLOCK



1;


=pod

=head1 NAME

ONVIF::PTZ::Elements::GetStatusResponse

=head1 DESCRIPTION

Perl data type class for the XML Schema defined element
GetStatusResponse from the namespace http://www.onvif.org/ver20/ptz/wsdl.







=head1 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

=over

=item * PTZStatus

 $element->set_PTZStatus($data);
 $element->get_PTZStatus();





=back


=head1 METHODS

=head2 new

 my $element = ONVIF::PTZ::Elements::GetStatusResponse->new($data);

Constructor. The following data structure may be passed to new():

 {
   PTZStatus =>  { # ONVIF::PTZ::Types::PTZStatus
     Position =>  { # ONVIF::PTZ::Types::PTZVector
       PanTilt => ,
       Zoom => ,
     },
     MoveStatus =>  { # ONVIF::PTZ::Types::PTZMoveStatus
       PanTilt => $some_value, # MoveStatus
       Zoom => $some_value, # MoveStatus
     },
     Error =>  $some_value, # string
     UtcTime =>  $some_value, # dateTime
   },
 },

=head1 AUTHOR

Generated by SOAP::WSDL

=cut

