#monitors {
    width: 100%;
    margin: 0 auto;
    text-align: center;
}

#monitors .monitorFrame {
    padding: 1px;
    float: left;
    width: 33%;
}

#monitors .monitor {
    text-align: center;
}

#monitorFrame0, #monitorFrame3, #monitorFrame6, #monitorFrame9, #monitorFrame12, #monitorFrame15 {
    clear: both;
}

#monitor0, #monitor3, #monitor6, #monitor9, #monitor12, #monitor15 {
    float: right;
}

#monitorFrame1, #monitorFrame4, #monitorFrame7, #monitorFrame10, #monitorFrame13, #monitorFrame16 {
    text-align: center;
}

#monitor1, #monitor4, #monitor7, #monitor10, #monitor13, #monitor16 {
}

#monitorFrame2, #monitorFrame5, #monitorFrame8, #monitorFrame11, #monitorFrame14, #monitorFrame17 {
}

#monitor2, #monitor5, #monitor8, #monitor11, #monitor14, #monitor17 {
    float: left;
}
