@charset "UTF-8";
/**
 * @author zhixin wen <wenzhixin2010@gmail.com>
 * https://github.com/wenzhixin/bootstrap-table/
 * theme: https://github.com/Semantic-Org/Semantic-UI
 */
/* stylelint-disable annotation-no-unknown, max-line-length */
/* stylelint-enable annotation-no-unknown, max-line-length */
.bootstrap-table .fixed-table-toolbar::after {
  content: "";
  display: block;
  clear: both;
}
.bootstrap-table .fixed-table-toolbar .bs-bars,
.bootstrap-table .fixed-table-toolbar .search,
.bootstrap-table .fixed-table-toolbar .columns {
  position: relative;
  margin-top: 10px;
  margin-bottom: 10px;
}
.bootstrap-table .fixed-table-toolbar .columns .btn-group > .btn-group {
  display: inline-block;
  margin-left: -1px !important;
}
.bootstrap-table .fixed-table-toolbar .columns .btn-group > .btn-group > .btn {
  border-radius: 0;
}
.bootstrap-table .fixed-table-toolbar .columns .btn-group > .btn-group:first-child > .btn {
  border-top-left-radius: 4px;
  border-bottom-left-radius: 4px;
}
.bootstrap-table .fixed-table-toolbar .columns .btn-group > .btn-group:last-child > .btn {
  border-top-right-radius: 4px;
  border-bottom-right-radius: 4px;
}
.bootstrap-table .fixed-table-toolbar .columns .dropdown-menu {
  text-align: left;
  max-height: 300px;
  overflow: auto;
  -ms-overflow-style: scrollbar;
  z-index: 1001;
}
.bootstrap-table .fixed-table-toolbar .columns label {
  display: block;
  padding: 3px 20px;
  clear: both;
  font-weight: normal;
  line-height: 1.4286;
}
.bootstrap-table .fixed-table-toolbar .columns-left {
  margin-right: 5px;
}
.bootstrap-table .fixed-table-toolbar .columns-right {
  margin-left: 5px;
}
.bootstrap-table .fixed-table-toolbar .pull-right .dropdown-menu {
  right: 0;
  left: auto;
}
.bootstrap-table .fixed-table-container {
  position: relative;
  clear: both;
}
.bootstrap-table .fixed-table-container .table {
  width: 100%;
  margin-bottom: 0 !important;
}
.bootstrap-table .fixed-table-container .table th,
.bootstrap-table .fixed-table-container .table td {
  vertical-align: middle;
  box-sizing: border-box;
}
.bootstrap-table .fixed-table-container .table thead th,
.bootstrap-table .fixed-table-container .table tfoot th {
  vertical-align: bottom;
  padding: 0;
  margin: 0;
}
.bootstrap-table .fixed-table-container .table thead th:focus,
.bootstrap-table .fixed-table-container .table tfoot th:focus {
  outline: 0 solid transparent;
}
.bootstrap-table .fixed-table-container .table thead th.detail,
.bootstrap-table .fixed-table-container .table tfoot th.detail {
  width: 30px;
}
.bootstrap-table .fixed-table-container .table thead th .th-inner,
.bootstrap-table .fixed-table-container .table tfoot th .th-inner {
  padding: 0.75rem;
  vertical-align: bottom;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.bootstrap-table .fixed-table-container .table thead th .sortable,
.bootstrap-table .fixed-table-container .table tfoot th .sortable {
  cursor: pointer;
  background-position: right;
  background-repeat: no-repeat;
  padding-right: 30px !important;
}
.bootstrap-table .fixed-table-container .table thead th .sortable.sortable-center,
.bootstrap-table .fixed-table-container .table tfoot th .sortable.sortable-center {
  padding-left: 20px !important;
  padding-right: 20px !important;
}
.bootstrap-table .fixed-table-container .table thead th .both,
.bootstrap-table .fixed-table-container .table tfoot th .both {
  background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 320 512" fill="%23dcdcdc"><path d="m103.05877,41.4c9.37707,-12.5 24.60541,-12.5 33.98248,0l96.02113,128c6.90152,9.2 8.92696,22.9 5.17614,34.9s-12.45274,19.8 -22.20489,19.8l-192.04225,-0.1c-9.67713,0 -18.45406,-7.8 -22.20489,-19.8s-1.65036,-25.7 5.17614,-34.9l96.02113,-128l0.07501,0.1zm0,429.3l-96.02113,-128c-6.90152,-9.2 -8.92696,-22.9 -5.17614,-34.9s12.45274,-19.8 22.20489,-19.8l192.04225,0c9.67713,0 18.45406,7.8 22.20489,19.8s1.65036,25.7 -5.17614,34.9l-96.02113,128c-9.37707,12.5 -24.60541,12.5 -33.98248,0l-0.07501,0z"/></svg>');
  background-size: 16px 16px;
  background-position: center right 2px;
}
.bootstrap-table .fixed-table-container .table thead th .asc,
.bootstrap-table .fixed-table-container .table tfoot th .asc {
  background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 320 512" fill="%237B83DB"><path d="m136.9496,41.4c-9.3763,-12.5 -24.60342,-12.5 -33.97972,0l-96.01334,128c-6.90096,9.2 -8.92624,22.9 -5.17572,34.9s12.45173,19.8 22.20309,19.8l192.02668,0c9.67634,0 18.45256,-7.8 22.20309,-19.8s1.65023,-25.7 -5.17572,-34.9l-96.01334,-128l-0.07501,0z"/></svg>');
}
.bootstrap-table .fixed-table-container .table thead th .desc,
.bootstrap-table .fixed-table-container .table tfoot th .desc {
  background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 320 512" fill="%237B83DB"><path d="m136.94959,471.6c-9.3763,12.5 -24.60342,12.5 -33.97972,0l-96.01334,-128c-6.90096,-9.2 -8.92624,-22.9 -5.17572,-34.9s12.45173,-19.8 22.20308,-19.8l192.02667,0c9.67634,0 18.45256,7.8 22.20308,19.8s1.65023,25.7 -5.17572,34.9l-96.01334,128l-0.07501,0z"/></svg>');
}
.bootstrap-table .fixed-table-container .table tbody tr.selected td {
  background-color: rgba(0, 0, 0, 0.075);
}
.bootstrap-table .fixed-table-container .table tbody tr.no-records-found td {
  text-align: center;
}
.bootstrap-table .fixed-table-container .table tbody tr .card-view {
  display: flex;
}
.bootstrap-table .fixed-table-container .table tbody tr .card-view .card-view-title {
  font-weight: bold;
  display: inline-block;
  min-width: 30%;
  width: auto !important;
  text-align: left !important;
}
.bootstrap-table .fixed-table-container .table tbody tr .card-view .card-view-value {
  width: 100% !important;
  text-align: left !important;
}
.bootstrap-table .fixed-table-container .table .bs-checkbox {
  text-align: center;
}
.bootstrap-table .fixed-table-container .table .bs-checkbox label {
  margin-bottom: 0;
}
.bootstrap-table .fixed-table-container .table .bs-checkbox label input[type=radio],
.bootstrap-table .fixed-table-container .table .bs-checkbox label input[type=checkbox] {
  margin: 0 auto !important;
}
.bootstrap-table .fixed-table-container .table.table-sm .th-inner {
  padding: 0.25rem;
}
.bootstrap-table .fixed-table-container.fixed-height:not(.has-footer) {
  border-bottom: 1px solid rgba(34, 36, 38, 0.1);
}
.bootstrap-table .fixed-table-container.fixed-height.has-card-view {
  border-top: 1px solid rgba(34, 36, 38, 0.1);
  border-bottom: 1px solid rgba(34, 36, 38, 0.1);
}
.bootstrap-table .fixed-table-container.fixed-height .fixed-table-border {
  border-left: 1px solid rgba(34, 36, 38, 0.1);
  border-right: 1px solid rgba(34, 36, 38, 0.1);
}
.bootstrap-table .fixed-table-container.fixed-height .table thead th {
  border-bottom: 1px solid rgba(34, 36, 38, 0.1);
}
.bootstrap-table .fixed-table-container.fixed-height .table-dark thead th {
  border-bottom: 1px solid #32383e;
}
.bootstrap-table .fixed-table-container .fixed-table-header {
  overflow: hidden;
}
.bootstrap-table .fixed-table-container .fixed-table-body {
  overflow: auto;
  height: 100%;
}
.bootstrap-table .fixed-table-container .fixed-table-body .fixed-table-loading {
  align-items: center;
  background: #fff;
  display: flex;
  justify-content: center;
  position: absolute;
  bottom: 0;
  width: 100%;
  max-width: 100%;
  z-index: 1000;
  transition: visibility 0s, opacity 0.15s ease-in-out;
  opacity: 0;
  visibility: hidden;
}
.bootstrap-table .fixed-table-container .fixed-table-body .fixed-table-loading.open {
  visibility: visible;
  opacity: 1;
}
.bootstrap-table .fixed-table-container .fixed-table-body .fixed-table-loading .loading-wrap {
  align-items: baseline;
  display: flex;
  justify-content: center;
}
.bootstrap-table .fixed-table-container .fixed-table-body .fixed-table-loading .loading-wrap .loading-text {
  margin-right: 6px;
}
.bootstrap-table .fixed-table-container .fixed-table-body .fixed-table-loading .loading-wrap .animation-wrap {
  align-items: center;
  display: flex;
  justify-content: center;
}
.bootstrap-table .fixed-table-container .fixed-table-body .fixed-table-loading .loading-wrap .animation-dot,
.bootstrap-table .fixed-table-container .fixed-table-body .fixed-table-loading .loading-wrap .animation-wrap::after,
.bootstrap-table .fixed-table-container .fixed-table-body .fixed-table-loading .loading-wrap .animation-wrap::before {
  content: "";
  animation-duration: 1.5s;
  animation-iteration-count: infinite;
  animation-name: loading;
  background: rgba(0, 0, 0, 0.87);
  border-radius: 50%;
  display: block;
  height: 5px;
  margin: 0 4px;
  opacity: 0;
  width: 5px;
}
.bootstrap-table .fixed-table-container .fixed-table-body .fixed-table-loading .loading-wrap .animation-dot {
  animation-delay: 0.3s;
}
.bootstrap-table .fixed-table-container .fixed-table-body .fixed-table-loading .loading-wrap .animation-wrap::after {
  animation-delay: 0.6s;
}
.bootstrap-table .fixed-table-container .fixed-table-body .fixed-table-loading.table-dark {
  background: rgba(0, 0, 0, 0.87);
}
.bootstrap-table .fixed-table-container .fixed-table-body .fixed-table-loading.table-dark .animation-dot,
.bootstrap-table .fixed-table-container .fixed-table-body .fixed-table-loading.table-dark .animation-wrap::after,
.bootstrap-table .fixed-table-container .fixed-table-body .fixed-table-loading.table-dark .animation-wrap::before {
  background: #fff;
}
.bootstrap-table .fixed-table-container .fixed-table-footer {
  overflow: hidden;
}
.bootstrap-table .fixed-table-pagination::after {
  content: "";
  display: block;
  clear: both;
}
.bootstrap-table .fixed-table-pagination > .pagination-detail,
.bootstrap-table .fixed-table-pagination > .pagination {
  margin-top: 10px;
  margin-bottom: 10px;
}
.bootstrap-table .fixed-table-pagination > .pagination-detail .pagination-info {
  line-height: 34px;
  margin-right: 5px;
}
.bootstrap-table .fixed-table-pagination > .pagination-detail .page-list {
  display: inline-block;
}
.bootstrap-table .fixed-table-pagination > .pagination-detail .page-list .btn-group {
  position: relative;
  display: inline-block;
  vertical-align: middle;
}
.bootstrap-table .fixed-table-pagination > .pagination-detail .page-list .btn-group .dropdown-menu {
  margin-bottom: 0;
}
.bootstrap-table .fixed-table-pagination > .pagination ul.pagination {
  margin: 0;
}
.bootstrap-table .fixed-table-pagination > .pagination ul.pagination li.page-intermediate a {
  color: #c8c8c8;
}
.bootstrap-table .fixed-table-pagination > .pagination ul.pagination li.page-intermediate a::before {
  content: "⬅";
}
.bootstrap-table .fixed-table-pagination > .pagination ul.pagination li.page-intermediate a::after {
  content: "➡";
}
.bootstrap-table .fixed-table-pagination > .pagination ul.pagination li.disabled a {
  pointer-events: none;
  cursor: default;
}
.bootstrap-table.fullscreen {
  position: fixed;
  top: 0;
  left: 0;
  z-index: 1050;
  width: 100% !important;
  background: #fff;
  height: 100vh;
  overflow-y: scroll;
}
.bootstrap-table.bootstrap4 .pagination-lg .page-link, .bootstrap-table.bootstrap5 .pagination-lg .page-link {
  padding: 0.5rem 1rem;
}
.bootstrap-table.bootstrap5 .float-left {
  float: left;
}
.bootstrap-table.bootstrap5 .float-right {
  float: right;
}

/* calculate scrollbar width */
div.fixed-table-scroll-inner {
  width: 100%;
  height: 200px;
}

div.fixed-table-scroll-outer {
  top: 0;
  left: 0;
  visibility: hidden;
  width: 200px;
  height: 150px;
  overflow: hidden;
}

@keyframes loading {
  0% {
    opacity: 0;
  }
  50% {
    opacity: 1;
  }
  100% {
    opacity: 0;
  }
}
.bootstrap-table .fixed-table-container.fixed-height:not(.has-footer),
.bootstrap-table .fixed-table-body {
  border-bottom-left-radius: 0.2857rem;
  border-bottom-right-radius: 0.2857rem;
}
.bootstrap-table .float-left {
  float: left;
}
.bootstrap-table .float-right {
  float: right;
}
.bootstrap-table .fixed-table-toolbar .search input {
  padding-top: 0.6071rem;
  padding-bottom: 0.6071rem;
}
.bootstrap-table .fixed-table-toolbar .button.dropdown {
  padding: 0;
}
.bootstrap-table .fixed-table-toolbar .button.dropdown .button {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
.bootstrap-table .fixed-table-toolbar .ui.buttons .button:last-child .button {
  border-top-right-radius: 0.2857rem;
  border-bottom-right-radius: 0.2857rem;
}
.bootstrap-table .fixed-table-header .table {
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
  border-bottom: none;
}
.bootstrap-table .table {
  background: transparent;
}
.bootstrap-table .table thead th[data-not-first-th] {
  border-left: 1px solid rgba(34, 36, 38, 0.1) !important;
}
.bootstrap-table .dropup i.icon.dropdown::before {
  content: "\f0d8";
}
