
package ONVIF::Media::Attributes::contentType;
use strict;
use warnings;

{ # BLOCK to scope variables

sub get_xmlns { 'http://www.w3.org/2005/05/xmlmime' }

__PACKAGE__->__set_name('contentType');
__PACKAGE__->__set_ref();

# atomic simpleType: <attribute><simpleType
use base qw(
    SOAP::WSDL::XSD::Typelib::Attribute
);
# derivation by restriction
use base qw(
    SOAP::WSDL::XSD::Typelib::Builtin::string);


}



1;


=pod

=head1 NAME

ONVIF::Media::Attributes::contentType

=head1 DESCRIPTION

Perl data type class for the XML Schema defined attribute
contentType from the namespace http://www.w3.org/2005/05/xmlmime.






This XML element type class has a atomic simpleType as it's base:



=head1 METHODS

=head2 new

 my $element = ONVIF::Media::Attributes::contentType->new($data);

Constructor. The following data structure may be passed to new():

 { value => $value }

=head1 AUTHOR

Generated by SOAP::WSDL

=cut

