#settingsPanel {
    float: left;
    margin: 0 2px;
}

#pluginSettings {
    border-collapse: collapse;
}

#pluginSettings th, #pluginSettings td {
    border: 1px solid #7f7fb2;
    padding: 3px;
    text-align: left;
}

#pluginSettings th[scope=row] {
    padding: 4px 3px 3px;
    vertical-align: top;
    white-space: nowrap;
}
