
package ONVIF::PTZ::Typemaps::PTZ;
use strict;
use warnings;

our $typemap_1 = {
               'GetConfigurationsResponse/PTZConfiguration/DefaultRelativePanTiltTranslationSpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'SetConfiguration/PTZConfiguration/PanTiltLimits/Range/YRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'AbsoluteMove/Position/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetPresetTourOptionsResponse/Options/TourSpot/PresetDetail/PresetToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/RelativePanTiltTranslationSpace/YRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetTour/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetPresetTourResponse/PresetTour/TourSpot/PresetDetail/TypeExtension' => 'ONVIF::PTZ::Types::PTZPresetTourTypeExtension',
               'GetPresetTourOptionsResponse/Options/TourSpot/PresetDetail' => 'ONVIF::PTZ::Types::PTZPresetTourPresetDetailOptions',
               'GetPresetToursResponse/PresetTour/StartingCondition/Direction' => 'ONVIF::PTZ::Types::PTZPresetTourDirection',
               'GetPresetTourOptionsResponse/Options/StartingCondition' => 'ONVIF::PTZ::Types::PTZPresetTourStartingConditionOptions',
               'SetConfiguration/PTZConfiguration/PanTiltLimits/Range/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetConfigurationResponse/PTZConfiguration/Name' => 'ONVIF::PTZ::Types::Name',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/AbsolutePanTiltPositionSpace' => 'ONVIF::PTZ::Types::Space2DDescription',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/DefaultPTZSpeed/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/ContinuousZoomVelocitySpace' => 'ONVIF::PTZ::Types::Space1DDescription',
               'GetConfigurationOptions' => 'ONVIF::PTZ::Elements::GetConfigurationOptions',
               'GetNodesResponse' => 'ONVIF::PTZ::Elements::GetNodesResponse',
               'ModifyPresetTour/PresetTour/StartingCondition/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourStartingConditionExtension',
               'GetNodeResponse/PTZNode/Extension' => 'ONVIF::PTZ::Types::PTZNodeExtension',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/RelativePanTiltTranslationSpace/YRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetConfigurationsResponse/PTZConfiguration/PanTiltLimits' => 'ONVIF::PTZ::Types::PanTiltLimits',
               'GetPresetToursResponse/PresetTour/Status/CurrentTourSpot/PresetDetail/PresetToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetServiceCapabilitiesResponse/Capabilities' => 'ONVIF::PTZ::Types::Capabilities',
               'GetConfigurationResponse/PTZConfiguration/Extension/PTControlDirection/Extension' => 'ONVIF::PTZ::Types::PTControlDirectionExtension',
               'Stop' => 'ONVIF::PTZ::Elements::Stop',
               'GetPresetToursResponse/PresetTour/StartingCondition/RecurringDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetPresetTourResponse/PresetTour/TourSpot/Speed/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'ModifyPresetTour/PresetTour/StartingCondition/RecurringTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/ZoomSpeedSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetsResponse' => 'ONVIF::PTZ::Elements::GetPresetsResponse',
               'GetConfigurationsResponse/PTZConfiguration/Extension/PTControlDirection/Extension' => 'ONVIF::PTZ::Types::PTControlDirectionExtension',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/ZoomLimits/Range/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'SetPreset/PresetName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'SetPreset/PresetToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetNodeResponse/PTZNode/MaximumNumberOfPresets' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'SetHomePositionResponse' => 'ONVIF::PTZ::Elements::SetHomePositionResponse',
               'GetStatusResponse/PTZStatus/Error' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'SetConfiguration/PTZConfiguration/Extension/PTControlDirection/Extension' => 'ONVIF::PTZ::Types::PTControlDirectionExtension',
               'ContinuousMoveResponse' => 'ONVIF::PTZ::Elements::ContinuousMoveResponse',
               'GetPresetToursResponse/PresetTour/StartingCondition/RecurringTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'ModifyPresetTour/PresetTour/TourSpot/Speed/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetNode' => 'ONVIF::PTZ::Elements::GetNode',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/Extension/PTControlDirection/Reverse' => 'ONVIF::PTZ::Types::Reverse',
               'GetConfiguration/PTZConfigurationToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/AbsolutePanTiltPositionSpace/YRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetPresetTourOptionsResponse/Options/TourSpot/PresetDetail/PanTiltPositionSpace/YRange' => 'ONVIF::PTZ::Types::FloatRange',
               'ModifyPresetTour/PresetTour/TourSpot/Speed' => 'ONVIF::PTZ::Types::PTZSpeed',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/AbsoluteZoomPositionSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetPresetTourResponse/PresetTour/TourSpot/StayTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetConfigurationsResponse/PTZConfiguration/DefaultAbsolutePantTiltPositionSpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/AbsoluteZoomPositionSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'RemovePresetTour/PresetTourToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'SetPreset' => 'ONVIF::PTZ::Elements::SetPreset',
               'SetConfiguration/PTZConfiguration' => 'ONVIF::PTZ::Types::PTZConfiguration',
               'GetConfigurationsResponse/PTZConfiguration/ZoomLimits/Range/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'ModifyPresetTourResponse' => 'ONVIF::PTZ::Elements::ModifyPresetTourResponse',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/AbsoluteZoomPositionSpace' => 'ONVIF::PTZ::Types::Space1DDescription',
               'RelativeMove/Speed/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GetConfigurationsResponse/PTZConfiguration/Name' => 'ONVIF::PTZ::Types::Name',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/Extension/PTControlDirection/EFlip/Mode' => 'ONVIF::PTZ::Types::EFlipMode',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/AbsolutePanTiltPositionSpace/YRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/AbsoluteZoomPositionSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/RelativeZoomTranslationSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/PTControlDirection/Reverse/Mode' => 'ONVIF::PTZ::Types::ReverseMode',
               'GetConfigurationResponse/PTZConfiguration/PanTiltLimits/Range/YRange' => 'ONVIF::PTZ::Types::FloatRange',
               'SetConfiguration/PTZConfiguration/PanTiltLimits/Range/YRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetConfigurationResponse/PTZConfiguration/PanTiltLimits/Range/YRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetToursResponse/PresetTour/TourSpot/PresetDetail' => 'ONVIF::PTZ::Types::PTZPresetTourPresetDetail',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/ZoomSpeedSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'SetConfiguration/PTZConfiguration/DefaultContinuousPanTiltVelocitySpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetPresetToursResponse' => 'ONVIF::PTZ::Elements::GetPresetToursResponse',
               'SetPresetResponse' => 'ONVIF::PTZ::Elements::SetPresetResponse',
               'GetPresetTourResponse/PresetTour/Name' => 'ONVIF::PTZ::Types::Name',
               'SendAuxiliaryCommand' => 'ONVIF::PTZ::Elements::SendAuxiliaryCommand',
               'GetConfigurationsResponse/PTZConfiguration/PanTiltLimits/Range/YRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/RelativePanTiltTranslationSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'RelativeMoveResponse' => 'ONVIF::PTZ::Elements::RelativeMoveResponse',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/AbsolutePanTiltPositionSpace' => 'ONVIF::PTZ::Types::Space2DDescription',
               'AbsoluteMove' => 'ONVIF::PTZ::Elements::AbsoluteMove',
               'GotoPreset/Speed' => 'ONVIF::PTZ::Types::PTZSpeed',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/ContinuousZoomVelocitySpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'ModifyPresetTour/PresetTour/Name' => 'ONVIF::PTZ::Types::Name',
               'SetConfiguration/PTZConfiguration/PanTiltLimits' => 'ONVIF::PTZ::Types::PanTiltLimits',
               'GetConfigurationResponse/PTZConfiguration/Extension/PTControlDirection/Reverse' => 'ONVIF::PTZ::Types::Reverse',
               'ModifyPresetTour/PresetTour/Status/CurrentTourSpot/Speed' => 'ONVIF::PTZ::Types::PTZSpeed',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/AbsolutePanTiltPositionSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/Extension/PTControlDirection/Reverse/Mode' => 'ONVIF::PTZ::Types::ReverseMode',
               'ModifyPresetTour/PresetTour/TourSpot/Speed/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'AbsoluteMoveResponse' => 'ONVIF::PTZ::Elements::AbsoluteMoveResponse',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/RelativePanTiltTranslationSpace/YRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetConfigurationResponse/PTZConfiguration/DefaultPTZTimeout' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'SendAuxiliaryCommand/AuxiliaryData' => 'ONVIF::PTZ::Types::AuxiliaryData',
               'CreatePresetTour/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetPresetToursResponse/PresetTour/TourSpot/PresetDetail/PTZPosition/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetPresetToursResponse/PresetTour/TourSpot/Speed/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/RelativePanTiltTranslationSpace/YRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetPresetToursResponse/PresetTour/Status/CurrentTourSpot/PresetDetail/PTZPosition/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetConfigurationResponse/PTZConfiguration/NodeToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'SetConfiguration/PTZConfiguration/NodeToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'SetConfiguration/PTZConfiguration/PanTiltLimits/Range' => 'ONVIF::PTZ::Types::Space2DDescription',
               'ModifyPresetTour/PresetTour/AutoStart' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/PanTiltSpeedSpace' => 'ONVIF::PTZ::Types::Space1DDescription',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/ContinuousZoomVelocitySpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetConfigurationsResponse/PTZConfiguration/Extension/PTControlDirection/Reverse' => 'ONVIF::PTZ::Types::Reverse',
               'GetPresetToursResponse/PresetTour/TourSpot/PresetDetail/PTZPosition' => 'ONVIF::PTZ::Types::PTZVector',
               'GetPresetTourResponse/PresetTour/Status/CurrentTourSpot' => 'ONVIF::PTZ::Types::PTZPresetTourSpot',
               'Stop/PanTilt' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/AbsoluteZoomPositionSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetConfigurationResponse/PTZConfiguration/ZoomLimits/Range/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNode/NodeToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/RelativePanTiltTranslationSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetConfigurationResponse/PTZConfiguration/PanTiltLimits/Range' => 'ONVIF::PTZ::Types::Space2DDescription',
               'GetServiceCapabilities' => 'ONVIF::PTZ::Elements::GetServiceCapabilities',
               'GetConfigurationResponse/PTZConfiguration/Extension/PTControlDirection/EFlip' => 'ONVIF::PTZ::Types::EFlip',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/PTControlDirection' => 'ONVIF::PTZ::Types::PTControlDirectionOptions',
               'GetConfigurationResponse/PTZConfiguration/PanTiltLimits/Range/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetNodesResponse/PTZNode/Extension/SupportedPresetTour/PTZPresetTourOperation' => 'ONVIF::PTZ::Types::PTZPresetTourOperation',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/AbsoluteZoomPositionSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/RelativePanTiltTranslationSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetPresetTour/PresetTourToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetConfigurationsResponse/PTZConfiguration/ZoomLimits/Range/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/AbsolutePanTiltPositionSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetNodeResponse/PTZNode/Extension/Extension' => 'ONVIF::PTZ::Types::PTZNodeExtension2',
               'GetNodesResponse/PTZNode/HomeSupported' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GotoHomePosition/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetPresetTourResponse/PresetTour/TourSpot/PresetDetail/PTZPosition' => 'ONVIF::PTZ::Types::PTZVector',
               'GotoPreset/Speed/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/AbsolutePanTiltPositionSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'Fault/detail' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/PanTiltLimits' => 'ONVIF::PTZ::Types::PanTiltLimits',
               'GetCompatibleConfigurations' => 'ONVIF::PTZ::Elements::GetCompatibleConfigurations',
               'SetConfiguration/PTZConfiguration/Name' => 'ONVIF::PTZ::Types::Name',
               'SetConfiguration/PTZConfiguration/UseCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/AbsoluteZoomPositionSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/ZoomLimits' => 'ONVIF::PTZ::Types::ZoomLimits',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/ContinuousPanTiltVelocitySpace/YRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/RelativePanTiltTranslationSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetConfigurationsResponse/PTZConfiguration/DefaultPTZSpeed/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/ContinuousPanTiltVelocitySpace/YRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/AbsoluteZoomPositionSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetConfigurationsResponse/PTZConfiguration/PanTiltLimits/Range/YRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/ContinuousPanTiltVelocitySpace/YRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'SetConfiguration/PTZConfiguration/PanTiltLimits/Range/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/AbsolutePanTiltPositionSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetPresetTourResponse/PresetTour/StartingCondition/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourStartingConditionExtension',
               'SetConfiguration/PTZConfiguration/DefaultPTZSpeed' => 'ONVIF::PTZ::Types::PTZSpeed',
               'GetConfigurationResponse/PTZConfiguration/PanTiltLimits/Range/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetConfigurationResponse/PTZConfiguration/Extension' => 'ONVIF::PTZ::Types::PTZConfigurationExtension',
               'GetNodesResponse/PTZNode/MaximumNumberOfPresets' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetPresetTourOptionsResponse/Options/TourSpot/PresetDetail/PanTiltPositionSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetConfigurationResponse/PTZConfiguration/DefaultRelativeZoomTranslationSpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'RemovePresetResponse' => 'ONVIF::PTZ::Elements::RemovePresetResponse',
               'GetConfigurationResponse/PTZConfiguration/UseCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetPresetToursResponse/PresetTour/Status/CurrentTourSpot' => 'ONVIF::PTZ::Types::PTZPresetTourSpot',
               'GetPresetTourResponse/PresetTour/Status/CurrentTourSpot/PresetDetail/Home' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/AbsolutePanTiltPositionSpace/YRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetTourOptionsResponse/Options/StartingCondition/RecurringDuration/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'ModifyPresetTour/PresetTour/TourSpot/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourSpotExtension',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/ContinuousPanTiltVelocitySpace/YRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetsResponse/Preset/Name' => 'ONVIF::PTZ::Types::Name',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/RelativeZoomTranslationSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetConfigurationsResponse/PTZConfiguration/ZoomLimits/Range' => 'ONVIF::PTZ::Types::Space1DDescription',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/PanTiltSpeedSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetPresetToursResponse/PresetTour/TourSpot/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourSpotExtension',
               'SendAuxiliaryCommand/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/ZoomSpeedSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetPresetToursResponse/PresetTour/TourSpot/StayTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetConfigurationsResponse/PTZConfiguration/NodeToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'RemovePresetTourResponse' => 'ONVIF::PTZ::Elements::RemovePresetTourResponse',
               'SetConfiguration/PTZConfiguration/Extension/PTControlDirection/EFlip/Mode' => 'ONVIF::PTZ::Types::EFlipMode',
               'GetPresetTourOptionsResponse/Options/TourSpot/PresetDetail/PanTiltPositionSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetPresetTourOptionsResponse/Options/StartingCondition/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourStartingConditionOptionsExtension',
               'GetConfigurationResponse/PTZConfiguration/PanTiltLimits' => 'ONVIF::PTZ::Types::PanTiltLimits',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/ZoomSpeedSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'ModifyPresetTour/PresetTour' => 'ONVIF::PTZ::Types::PresetTour',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/ContinuousPanTiltVelocitySpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetCompatibleConfigurations/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/PanTiltLimits/Range/YRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GotoPreset/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetPresets/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetPresetTourOptionsResponse/Options/StartingCondition/RecurringTime/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetCompatibleConfigurationsResponse' => 'ONVIF::PTZ::Elements::GetCompatibleConfigurationsResponse',
               'GetPresetToursResponse/PresetTour/StartingCondition' => 'ONVIF::PTZ::Types::PTZPresetTourStartingCondition',
               'GetPresetTourResponse/PresetTour/Status/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourStatusExtension',
               'ModifyPresetTour' => 'ONVIF::PTZ::Elements::ModifyPresetTour',
               'ModifyPresetTour/PresetTour/Status/CurrentTourSpot/PresetDetail/PresetToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'SendAuxiliaryCommandResponse/AuxiliaryResponse' => 'ONVIF::PTZ::Types::AuxiliaryData',
               'GetPresetToursResponse/PresetTour/Status/State' => 'ONVIF::PTZ::Types::PTZPresetTourState',
               'GotoPresetResponse' => 'ONVIF::PTZ::Elements::GotoPresetResponse',
               'GotoHomePositionResponse' => 'ONVIF::PTZ::Elements::GotoHomePositionResponse',
               'RemovePresetTour' => 'ONVIF::PTZ::Elements::RemovePresetTour',
               'GetConfigurationResponse/PTZConfiguration/PanTiltLimits/Range/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/PanTiltSpeedSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'CreatePresetTour' => 'ONVIF::PTZ::Elements::CreatePresetTour',
               'GetPresetTourResponse/PresetTour/Status/State' => 'ONVIF::PTZ::Types::PTZPresetTourState',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/ContinuousPanTiltVelocitySpace' => 'ONVIF::PTZ::Types::Space2DDescription',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/ZoomSpeedSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/AbsoluteZoomPositionSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'ModifyPresetTour/PresetTour/Status/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourStatusExtension',
               'GetPresetTourOptionsResponse' => 'ONVIF::PTZ::Elements::GetPresetTourOptionsResponse',
               'GetPresetTourOptionsResponse/Options/TourSpot/StayTime/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'SetConfiguration/PTZConfiguration/Extension/PTControlDirection/Reverse/Mode' => 'ONVIF::PTZ::Types::ReverseMode',
               'GetPresetTourResponse/PresetTour/Status/CurrentTourSpot/PresetDetail/PTZPosition/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetConfigurationsResponse/PTZConfiguration/ZoomLimits/Range/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'SetConfigurationResponse' => 'ONVIF::PTZ::Elements::SetConfigurationResponse',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/RelativePanTiltTranslationSpace' => 'ONVIF::PTZ::Types::Space2DDescription',
               'GetConfigurationsResponse/PTZConfiguration/PanTiltLimits/Range/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/AbsoluteZoomPositionSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'SetConfiguration/PTZConfiguration/DefaultContinuousZoomVelocitySpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetConfiguration' => 'ONVIF::PTZ::Elements::GetConfiguration',
               'GetConfigurationResponse/PTZConfiguration/DefaultAbsoluteZoomPositionSpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'AbsoluteMove/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetPresetTourResponse/PresetTour/TourSpot/PresetDetail' => 'ONVIF::PTZ::Types::PTZPresetTourPresetDetail',
               'ModifyPresetTour/PresetTour/TourSpot/PresetDetail/PTZPosition' => 'ONVIF::PTZ::Types::PTZVector',
               'SetConfiguration/PTZConfiguration/ZoomLimits/Range/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/RelativePanTiltTranslationSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/ZoomSpeedSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GotoPreset/Speed/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/DefaultAbsolutePantTiltPositionSpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'SetConfiguration/PTZConfiguration/Extension' => 'ONVIF::PTZ::Types::PTZConfigurationExtension',
               'GetPresetTourResponse/PresetTour/TourSpot/Speed' => 'ONVIF::PTZ::Types::PTZSpeed',
               'GetPresetToursResponse/PresetTour/TourSpot/Speed' => 'ONVIF::PTZ::Types::PTZSpeed',
               'GetConfigurationResponse/PTZConfiguration/ZoomLimits' => 'ONVIF::PTZ::Types::ZoomLimits',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/ContinuousZoomVelocitySpace' => 'ONVIF::PTZ::Types::Space1DDescription',
               'GetPresetTourOptionsResponse/Options/TourSpot/PresetDetail/ZoomPositionSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/ZoomLimits/Range/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetPresetTourResponse/PresetTour/Status/CurrentTourSpot/StayTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'SetConfiguration/PTZConfiguration/Extension/PTControlDirection' => 'ONVIF::PTZ::Types::PTControlDirection',
               'SetPresetResponse/PresetToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'SetConfiguration/PTZConfiguration/DefaultRelativeZoomTranslationSpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/DefaultPTZTimeout' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/RelativeZoomTranslationSpace' => 'ONVIF::PTZ::Types::Space1DDescription',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/AbsoluteZoomPositionSpace' => 'ONVIF::PTZ::Types::Space1DDescription',
               'ModifyPresetTour/PresetTour/StartingCondition/Direction' => 'ONVIF::PTZ::Types::PTZPresetTourDirection',
               'GotoHomePosition' => 'ONVIF::PTZ::Elements::GotoHomePosition',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/DefaultRelativePanTiltTranslationSpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/ContinuousPanTiltVelocitySpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'RelativeMove/Speed' => 'ONVIF::PTZ::Types::PTZSpeed',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/ZoomSpeedSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetConfigurationOptionsResponse' => 'ONVIF::PTZ::Elements::GetConfigurationOptionsResponse',
               'GetConfigurations' => 'ONVIF::PTZ::Elements::GetConfigurations',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/AbsolutePanTiltPositionSpace/YRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/ContinuousPanTiltVelocitySpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/ContinuousPanTiltVelocitySpace/YRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/AbsoluteZoomPositionSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetTourResponse/PresetTour/StartingCondition' => 'ONVIF::PTZ::Types::PTZPresetTourStartingCondition',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/ContinuousPanTiltVelocitySpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'SetHomePosition/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/ZoomLimits/Range' => 'ONVIF::PTZ::Types::Space1DDescription',
               'GetPresetToursResponse/PresetTour/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourExtension',
               'GetConfigurationResponse/PTZConfiguration/Extension/Extension' => 'ONVIF::PTZ::Types::PTZConfigurationExtension2',
               'GetConfigurationResponse/PTZConfiguration/Extension/PTControlDirection' => 'ONVIF::PTZ::Types::PTControlDirection',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/ContinuousPanTiltVelocitySpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNodeResponse/PTZNode/HomeSupported' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'AbsoluteMove/Position' => 'ONVIF::PTZ::Types::PTZVector',
               'RemovePreset/PresetToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/AbsolutePanTiltPositionSpace/YRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetStatusResponse/PTZStatus/MoveStatus' => 'ONVIF::PTZ::Types::PTZMoveStatus',
               'GetConfigurationsResponse/PTZConfiguration/Extension/PTControlDirection/EFlip' => 'ONVIF::PTZ::Types::EFlip',
               'SetConfiguration/PTZConfiguration/DefaultRelativePanTiltTranslationSpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/PanTiltSpeedSpace' => 'ONVIF::PTZ::Types::Space1DDescription',
               'SetConfiguration/PTZConfiguration/DefaultAbsoluteZoomPositionSpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/ContinuousPanTiltVelocitySpace/YRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetStatus/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/RelativeZoomTranslationSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'ModifyPresetTour/PresetTour/TourSpot/PresetDetail/PTZPosition/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/ContinuousZoomVelocitySpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/ContinuousZoomVelocitySpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/UseCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/PanTiltLimits/Range' => 'ONVIF::PTZ::Types::Space2DDescription',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/ContinuousZoomVelocitySpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'StopResponse' => 'ONVIF::PTZ::Elements::StopResponse',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/ContinuousZoomVelocitySpace' => 'ONVIF::PTZ::Types::Space1DDescription',
               'GetPresetTourResponse/PresetTour/Status/CurrentTourSpot/Speed/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/PTControlDirection/Extension' => 'ONVIF::PTZ::Types::PTControlDirectionOptionsExtension',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/AbsolutePanTiltPositionSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'ModifyPresetTour/PresetTour/Status/CurrentTourSpot/PresetDetail/TypeExtension' => 'ONVIF::PTZ::Types::PTZPresetTourTypeExtension',
               'GetPresetTourResponse/PresetTour/Status' => 'ONVIF::PTZ::Types::PTZPresetTourStatus',
               'GetConfigurationsResponse/PTZConfiguration/Extension/Extension' => 'ONVIF::PTZ::Types::PTZConfigurationExtension2',
               'ModifyPresetTour/PresetTour/Status/CurrentTourSpot/Speed/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GetPresetToursResponse/PresetTour/Status/CurrentTourSpot/Speed' => 'ONVIF::PTZ::Types::PTZSpeed',
               'GetStatus' => 'ONVIF::PTZ::Elements::GetStatus',
               'GetConfigurationResponse/PTZConfiguration/DefaultRelativePanTiltTranslationSpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetPresetToursResponse/PresetTour/Status/CurrentTourSpot/Speed/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GetPresetTourResponse/PresetTour/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourExtension',
               'GetConfigurationResponse/PTZConfiguration/DefaultAbsolutePantTiltPositionSpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/RelativePanTiltTranslationSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/PTZTimeout/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/ContinuousZoomVelocitySpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetPresetToursResponse/PresetTour/AutoStart' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetStatusResponse' => 'ONVIF::PTZ::Elements::GetStatusResponse',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/ContinuousZoomVelocitySpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/DefaultContinuousPanTiltVelocitySpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/Extension/Extension' => 'ONVIF::PTZ::Types::PTZConfigurationExtension2',
               'GetNodesResponse/PTZNode/AuxiliaryCommands' => 'ONVIF::PTZ::Types::AuxiliaryData',
               'SetPreset/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'ContinuousMove/Velocity' => 'ONVIF::PTZ::Types::PTZSpeed',
               'GetPresetToursResponse/PresetTour/Status/CurrentTourSpot/PresetDetail/PTZPosition' => 'ONVIF::PTZ::Types::PTZVector',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/ContinuousPanTiltVelocitySpace/YRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'ContinuousMove/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetConfigurationsResponse/PTZConfiguration/DefaultContinuousZoomVelocitySpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetPresetTourOptionsResponse/Options/TourSpot/PresetDetail/ZoomPositionSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetPresetToursResponse/PresetTour/TourSpot/PresetDetail/Home' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetPresetToursResponse/PresetTour/TourSpot/PresetDetail/PresetToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/ZoomSpeedSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetConfigurationResponse' => 'ONVIF::PTZ::Elements::GetConfigurationResponse',
               'GotoHomePosition/Speed/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'ModifyPresetTour/PresetTour/Status/State' => 'ONVIF::PTZ::Types::PTZPresetTourState',
               'GetPresetTourOptionsResponse/Options/StartingCondition/RecurringTime/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/AbsolutePanTiltPositionSpace/YRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetPresetTourOptionsResponse/Options/TourSpot/PresetDetail/PanTiltPositionSpace/YRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNodes' => 'ONVIF::PTZ::Elements::GetNodes',
               'GetPresetTourOptionsResponse/Options/StartingCondition/RecurringDuration/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'SetConfiguration/PTZConfiguration/ZoomLimits/Range/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetPresetToursResponse/PresetTour/TourSpot/PresetDetail/TypeExtension' => 'ONVIF::PTZ::Types::PTZPresetTourTypeExtension',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/RelativeZoomTranslationSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'CreatePresetTourResponse' => 'ONVIF::PTZ::Elements::CreatePresetTourResponse',
               'GetPresetTourResponse/PresetTour/TourSpot/Speed/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/Extension/PTControlDirection' => 'ONVIF::PTZ::Types::PTControlDirection',
               'ModifyPresetTour/PresetTour/Status/CurrentTourSpot/PresetDetail' => 'ONVIF::PTZ::Types::PTZPresetTourPresetDetail',
               'GetPresetToursResponse/PresetTour/Status/CurrentTourSpot/Speed/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'ContinuousMove/Velocity/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'SetConfiguration/PTZConfiguration/PanTiltLimits/Range/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetPresetTourOptionsResponse/Options/TourSpot/PresetDetail/ZoomPositionSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/RelativeZoomTranslationSpace' => 'ONVIF::PTZ::Types::Space1DDescription',
               'GetPresetTourResponse/PresetTour/Status/CurrentTourSpot/Speed' => 'ONVIF::PTZ::Types::PTZSpeed',
               'SetConfiguration/PTZConfiguration/Extension/PTControlDirection/Reverse' => 'ONVIF::PTZ::Types::Reverse',
               'GetConfigurationsResponse/PTZConfiguration/DefaultAbsoluteZoomPositionSpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'ModifyPresetTour/PresetTour/TourSpot' => 'ONVIF::PTZ::Types::PTZPresetTourSpot',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/RelativePanTiltTranslationSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'ModifyPresetTour/PresetTour/TourSpot/PresetDetail/TypeExtension' => 'ONVIF::PTZ::Types::PTZPresetTourTypeExtension',
               'GetConfigurationResponse/PTZConfiguration/ZoomLimits/Range/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'ModifyPresetTour/PresetTour/Status/CurrentTourSpot/StayTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetStatusResponse/PTZStatus/UtcTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'GetPresetToursResponse/PresetTour/Status/CurrentTourSpot/StayTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetConfigurationResponse/PTZConfiguration/DefaultPTZSpeed/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetPresetTourResponse' => 'ONVIF::PTZ::Elements::GetPresetTourResponse',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/RelativeZoomTranslationSpace' => 'ONVIF::PTZ::Types::Space1DDescription',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/AbsolutePanTiltPositionSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetToursResponse/PresetTour/TourSpot' => 'ONVIF::PTZ::Types::PTZPresetTourSpot',
               'RelativeMove/Translation/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/DefaultRelativeZoomTranslationSpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetPresetTourOptionsResponse/Options/TourSpot/StayTime/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/AbsolutePanTiltPositionSpace/YRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetTourResponse/PresetTour/TourSpot/PresetDetail/Home' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetPresetToursResponse/PresetTour/Status/CurrentTourSpot/PresetDetail/PTZPosition/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GetConfigurationResponse/PTZConfiguration/Extension/PTControlDirection/EFlip/Mode' => 'ONVIF::PTZ::Types::EFlipMode',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/PanTiltLimits/Range/YRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetTourOptionsResponse/Options/TourSpot/PresetDetail/ZoomPositionSpace' => 'ONVIF::PTZ::Types::Space1DDescription',
               'GetNodeResponse/PTZNode' => 'ONVIF::PTZ::Types::PTZNode',
               'GetPresetsResponse/Preset/PTZPosition/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/Extension' => 'ONVIF::PTZ::Types::PTZSpacesExtension',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/RelativePanTiltTranslationSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/ContinuousPanTiltVelocitySpace/YRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetPresetToursResponse/PresetTour/Status/CurrentTourSpot/PresetDetail/Home' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'OperatePresetTour' => 'ONVIF::PTZ::Elements::OperatePresetTour',
               'OperatePresetTourResponse' => 'ONVIF::PTZ::Elements::OperatePresetTourResponse',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/ZoomSpeedSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetConfigurationResponse/PTZConfiguration/ZoomLimits/Range' => 'ONVIF::PTZ::Types::Space1DDescription',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/RelativePanTiltTranslationSpace/YRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetTourResponse/PresetTour/TourSpot/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourSpotExtension',
               'GetPresetToursResponse/PresetTour/TourSpot/PresetDetail/PTZPosition/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GotoPreset' => 'ONVIF::PTZ::Elements::GotoPreset',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/RelativeZoomTranslationSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/Name' => 'ONVIF::PTZ::Types::Name',
               'GetConfigurationResponse/PTZConfiguration/DefaultContinuousPanTiltVelocitySpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetNodeResponse/PTZNode/Name' => 'ONVIF::PTZ::Types::Name',
               'GetConfigurationResponse/PTZConfiguration' => 'ONVIF::PTZ::Types::PTZConfiguration',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'CreatePresetTourResponse/PresetTourToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/ContinuousZoomVelocitySpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetTourResponse/PresetTour/Status/CurrentTourSpot/PresetDetail/PTZPosition/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'Stop/Zoom' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/ContinuousZoomVelocitySpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetNodeResponse/PTZNode/AuxiliaryCommands' => 'ONVIF::PTZ::Types::AuxiliaryData',
               'GetConfigurationOptions/ConfigurationToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetConfigurationResponse/PTZConfiguration/PanTiltLimits/Range/YRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetTourOptionsResponse/Options/TourSpot/PresetDetail/PanTiltPositionSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetNodeResponse' => 'ONVIF::PTZ::Elements::GetNodeResponse',
               'GetConfigurationsResponse' => 'ONVIF::PTZ::Elements::GetConfigurationsResponse',
               'GetStatusResponse/PTZStatus' => 'ONVIF::PTZ::Types::PTZStatus',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/ContinuousPanTiltVelocitySpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'OperatePresetTour/PresetTourToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'RelativeMove/Translation/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'SetConfiguration/PTZConfiguration/DefaultPTZTimeout' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/PanTiltLimits/Range/YRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/PanTiltSpeedSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces' => 'ONVIF::PTZ::Types::PTZSpaces',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/PTControlDirection/EFlip/Mode' => 'ONVIF::PTZ::Types::EFlipMode',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/ContinuousZoomVelocitySpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetStatusResponse/PTZStatus/MoveStatus/PanTilt' => 'ONVIF::PTZ::Types::MoveStatus',
               'ModifyPresetTour/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/PanTiltSpeedSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/AbsolutePanTiltPositionSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetsResponse/Preset/PTZPosition' => 'ONVIF::PTZ::Types::PTZVector',
               'SetConfiguration/PTZConfiguration/Extension/Extension' => 'ONVIF::PTZ::Types::PTZConfigurationExtension2',
               'GetConfigurationsResponse/PTZConfiguration/PanTiltLimits/Range' => 'ONVIF::PTZ::Types::Space2DDescription',
               'SetConfiguration/PTZConfiguration/ZoomLimits/Range/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/RelativePanTiltTranslationSpace/YRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetToursResponse/PresetTour' => 'ONVIF::PTZ::Types::PresetTour',
               'GetNodesResponse/PTZNode/Extension' => 'ONVIF::PTZ::Types::PTZNodeExtension',
               'SetConfiguration/PTZConfiguration/DefaultPTZSpeed/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/ContinuousPanTiltVelocitySpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GotoPreset/PresetToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/PTControlDirection/Reverse/Extension' => 'ONVIF::PTZ::Types::ReverseOptionsExtension',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/ContinuousPanTiltVelocitySpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'ModifyPresetTour/PresetTour/TourSpot/PresetDetail/PTZPosition/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'AbsoluteMove/Speed/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetNodeResponse/PTZNode/Extension/SupportedPresetTour' => 'ONVIF::PTZ::Types::PTZPresetTourSupported',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/Extension/PTControlDirection/EFlip' => 'ONVIF::PTZ::Types::EFlip',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/PanTiltSpeedSpace' => 'ONVIF::PTZ::Types::Space1DDescription',
               'SendAuxiliaryCommandResponse' => 'ONVIF::PTZ::Elements::SendAuxiliaryCommandResponse',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces' => 'ONVIF::PTZ::Types::PTZSpaces',
               'GetConfigurationsResponse/PTZConfiguration/ZoomLimits/Range/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'OperatePresetTour/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetPresetTourResponse/PresetTour/StartingCondition/RecurringDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/ZoomSpeedSpace' => 'ONVIF::PTZ::Types::Space1DDescription',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/RelativeZoomTranslationSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetPresetTourOptionsResponse/Options/TourSpot/PresetDetail/PanTiltPositionSpace/YRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/PanTiltSpeedSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetConfigurationsResponse/PTZConfiguration' => 'ONVIF::PTZ::Types::PTZConfiguration',
               'GetConfigurationsResponse/PTZConfiguration/DefaultPTZSpeed' => 'ONVIF::PTZ::Types::PTZSpeed',
               'RemovePresetTour/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'ModifyPresetTour/PresetTour/Status/CurrentTourSpot/PresetDetail/PTZPosition/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetCompatibleConfigurationsResponse/PTZConfiguration' => 'ONVIF::PTZ::Types::PTZConfiguration',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/PanTiltLimits/Range/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/Extension/PTControlDirection/Extension' => 'ONVIF::PTZ::Types::PTControlDirectionExtension',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/ContinuousPanTiltVelocitySpace' => 'ONVIF::PTZ::Types::Space2DDescription',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/RelativeZoomTranslationSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetServiceCapabilitiesResponse' => 'ONVIF::PTZ::Elements::GetServiceCapabilitiesResponse',
               'GetConfigurationsResponse/PTZConfiguration/Extension/PTControlDirection/EFlip/Mode' => 'ONVIF::PTZ::Types::EFlipMode',
               'GetConfigurationsResponse/PTZConfiguration/UseCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GotoHomePosition/Speed' => 'ONVIF::PTZ::Types::PTZSpeed',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/AbsolutePanTiltPositionSpace/YRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetToursResponse/PresetTour/Status' => 'ONVIF::PTZ::Types::PTZPresetTourStatus',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'RelativeMove/Translation' => 'ONVIF::PTZ::Types::PTZVector',
               'ModifyPresetTour/PresetTour/TourSpot/PresetDetail/PresetToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/AbsolutePanTiltPositionSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetPresetsResponse/Preset/PTZPosition/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/NodeToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetPresetTours' => 'ONVIF::PTZ::Elements::GetPresetTours',
               'GetPresetTour' => 'ONVIF::PTZ::Elements::GetPresetTour',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/ContinuousZoomVelocitySpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetTourOptionsResponse/Options/AutoStart' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'ContinuousMove/Timeout' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/PTZTimeout' => 'ONVIF::PTZ::Types::DurationRange',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/PTControlDirection/EFlip/Extension' => 'ONVIF::PTZ::Types::EFlipOptionsExtension',
               'ModifyPresetTour/PresetTour/Status/CurrentTourSpot/PresetDetail/PTZPosition/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/Extension' => 'ONVIF::PTZ::Types::PTZSpacesExtension',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/RelativePanTiltTranslationSpace/YRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/RelativeZoomTranslationSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'ModifyPresetTour/PresetTour/Status/CurrentTourSpot/PresetDetail/Home' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'RelativeMove' => 'ONVIF::PTZ::Elements::RelativeMove',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/PanTiltSpeedSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetsResponse/Preset' => 'ONVIF::PTZ::Types::PTZPreset',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/RelativePanTiltTranslationSpace/YRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/DefaultContinuousZoomVelocitySpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'SetConfiguration' => 'ONVIF::PTZ::Elements::SetConfiguration',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/PanTiltSpeedSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetConfigurationsResponse/PTZConfiguration/PanTiltLimits/Range/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetConfigurationResponse/PTZConfiguration/DefaultPTZSpeed/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GetPresetTourResponse/PresetTour/StartingCondition/RecurringTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/ContinuousPanTiltVelocitySpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetPresetTourOptions' => 'ONVIF::PTZ::Elements::GetPresetTourOptions',
               'GetPresetTourResponse/PresetTour/Status/CurrentTourSpot/PresetDetail' => 'ONVIF::PTZ::Types::PTZPresetTourPresetDetail',
               'GetPresetToursResponse/PresetTour/TourSpot/Speed/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/PanTiltLimits/Range/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/DefaultAbsoluteZoomPositionSpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetPresetTourResponse/PresetTour/Status/CurrentTourSpot/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourSpotExtension',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/AbsolutePanTiltPositionSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetTourResponse/PresetTour/TourSpot/PresetDetail/PresetToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/Extension' => 'ONVIF::PTZ::Types::PTZSpacesExtension',
               'SetConfiguration/PTZConfiguration/PanTiltLimits/Range/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/DefaultPTZSpeed/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetPresetTourResponse/PresetTour/Status/CurrentTourSpot/PresetDetail/PTZPosition' => 'ONVIF::PTZ::Types::PTZVector',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/ContinuousPanTiltVelocitySpace' => 'ONVIF::PTZ::Types::Space2DDescription',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/PTZTimeout/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/RelativePanTiltTranslationSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'SetConfiguration/PTZConfiguration/Extension/PTControlDirection/EFlip' => 'ONVIF::PTZ::Types::EFlip',
               'ModifyPresetTour/PresetTour/Status' => 'ONVIF::PTZ::Types::PTZPresetTourStatus',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/AbsoluteZoomPositionSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetTourOptionsResponse/Options/TourSpot/PresetDetail/PanTiltPositionSpace' => 'ONVIF::PTZ::Types::Space2DDescription',
               'GetStatusResponse/PTZStatus/Position/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GetConfigurationsResponse/PTZConfiguration/Extension/PTControlDirection/Reverse/Mode' => 'ONVIF::PTZ::Types::ReverseMode',
               'ModifyPresetTour/PresetTour/TourSpot/StayTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/AbsolutePanTiltPositionSpace/YRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetConfigurationResponse/PTZConfiguration/Extension/PTControlDirection/Reverse/Mode' => 'ONVIF::PTZ::Types::ReverseMode',
               'GetPresetTourResponse/PresetTour' => 'ONVIF::PTZ::Types::PresetTour',
               'GetNodesResponse/PTZNode/Extension/SupportedPresetTour/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourSupportedExtension',
               'GetPresetTourOptionsResponse/Options/TourSpot/PresetDetail/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourPresetDetailOptionsExtension',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/AbsolutePanTiltPositionSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNodesResponse/PTZNode/Extension/Extension' => 'ONVIF::PTZ::Types::PTZNodeExtension2',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/AbsoluteZoomPositionSpace' => 'ONVIF::PTZ::Types::Space1DDescription',
               'GetPresetTourOptionsResponse/Options/TourSpot/PresetDetail/ZoomPositionSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'OperatePresetTour/Operation' => 'ONVIF::PTZ::Types::PTZPresetTourOperation',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/RelativeZoomTranslationSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetTourOptionsResponse/Options/TourSpot/PresetDetail/Home' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'ModifyPresetTour/PresetTour/StartingCondition' => 'ONVIF::PTZ::Types::PTZPresetTourStartingCondition',
               'GetPresetTourResponse/PresetTour/AutoStart' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'ModifyPresetTour/PresetTour/Status/CurrentTourSpot/PresetDetail/PTZPosition' => 'ONVIF::PTZ::Types::PTZVector',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/RelativePanTiltTranslationSpace' => 'ONVIF::PTZ::Types::Space2DDescription',
               'GetConfigurationsResponse/PTZConfiguration/PanTiltLimits/Range/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/RelativeZoomTranslationSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'ModifyPresetTour/PresetTour/Status/CurrentTourSpot/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourSpotExtension',
               'SetConfiguration/ForcePersistence' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'GetConfigurationResponse/PTZConfiguration/ZoomLimits/Range/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetConfigurationsResponse/PTZConfiguration/DefaultPTZSpeed/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetPresetTourOptions/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/ZoomLimits/Range/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetToursResponse/PresetTour/Status/CurrentTourSpot/PresetDetail/TypeExtension' => 'ONVIF::PTZ::Types::PTZPresetTourTypeExtension',
               'GetNodeResponse/PTZNode/Extension/SupportedPresetTour/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourSupportedExtension',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/PTControlDirection/EFlip' => 'ONVIF::PTZ::Types::EFlipOptions',
               'GetNodesResponse/PTZNode/Extension/SupportedPresetTour' => 'ONVIF::PTZ::Types::PTZPresetTourSupported',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/ContinuousPanTiltVelocitySpace/YRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetPresetToursResponse/PresetTour/Status/CurrentTourSpot/PresetDetail' => 'ONVIF::PTZ::Types::PTZPresetTourPresetDetail',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/PanTiltSpeedSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'ModifyPresetTour/PresetTour/Status/CurrentTourSpot' => 'ONVIF::PTZ::Types::PTZPresetTourSpot',
               'GetNodesResponse/PTZNode/Name' => 'ONVIF::PTZ::Types::Name',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/ContinuousPanTiltVelocitySpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetToursResponse/PresetTour/StartingCondition/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourStartingConditionExtension',
               'SetConfiguration/PTZConfiguration/ZoomLimits' => 'ONVIF::PTZ::Types::ZoomLimits',
               'RelativeMove/Speed/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'AbsoluteMove/Speed' => 'ONVIF::PTZ::Types::PTZSpeed',
               'GetConfigurationsResponse/PTZConfiguration/PanTiltLimits/Range/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'ModifyPresetTour/PresetTour/TourSpot/PresetDetail/Home' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'SetConfiguration/PTZConfiguration/PanTiltLimits/Range/YRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetConfigurationsResponse/PTZConfiguration/DefaultPTZTimeout' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/RelativePanTiltTranslationSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'SetConfiguration/PTZConfiguration/ZoomLimits/Range/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'ContinuousMove/Velocity/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetStatusResponse/PTZStatus/Position/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/RelativePanTiltTranslationSpace/YRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetConfigurationResponse/PTZConfiguration/ZoomLimits/Range/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'SetConfiguration/PTZConfiguration/DefaultAbsolutePantTiltPositionSpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetPresetTourOptionsResponse/Options/TourSpot' => 'ONVIF::PTZ::Types::PTZPresetTourSpotOptions',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/PTControlDirection/Reverse' => 'ONVIF::PTZ::Types::ReverseOptions',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/RelativeZoomTranslationSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetConfigurationsResponse/PTZConfiguration/Extension/PTControlDirection' => 'ONVIF::PTZ::Types::PTControlDirection',
               'GetPresetTourResponse/PresetTour/TourSpot/PresetDetail/PTZPosition/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GetPresetTourResponse/PresetTour/TourSpot' => 'ONVIF::PTZ::Types::PTZPresetTourSpot',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/RelativePanTiltTranslationSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/RelativeZoomTranslationSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetPresetTourOptions/PresetTourToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetPresetTourOptionsResponse/Options' => 'ONVIF::PTZ::Types::PTZPresetTourOptions',
               'RemovePreset/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/ZoomSpeedSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetTours/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetNodesResponse/PTZNode/Extension/SupportedPresetTour/MaximumNumberOfPresetTours' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetPresetTourResponse/PresetTour/Status/CurrentTourSpot/PresetDetail/PresetToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/PanTiltLimits/Range/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'SetHomePosition' => 'ONVIF::PTZ::Elements::SetHomePosition',
               'GetPresetToursResponse/PresetTour/Status/CurrentTourSpot/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourSpotExtension',
               'GetPresetTourResponse/PresetTour/StartingCondition/Direction' => 'ONVIF::PTZ::Types::PTZPresetTourDirection',
               'GotoHomePosition/Speed/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetNodeResponse/PTZNode/Extension/SupportedPresetTour/MaximumNumberOfPresetTours' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/ZoomSpeedSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/ContinuousPanTiltVelocitySpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetConfigurationResponse/PTZConfiguration/DefaultContinuousZoomVelocitySpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/DefaultPTZSpeed' => 'ONVIF::PTZ::Types::PTZSpeed',
               'SetConfiguration/PTZConfiguration/ZoomLimits/Range' => 'ONVIF::PTZ::Types::Space1DDescription',
               'GetConfigurationsResponse/PTZConfiguration/DefaultContinuousPanTiltVelocitySpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/RelativePanTiltTranslationSpace' => 'ONVIF::PTZ::Types::Space2DDescription',
               'AbsoluteMove/Speed/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GetPresetTourOptionsResponse/Options/StartingCondition/RecurringDuration' => 'ONVIF::PTZ::Types::DurationRange',
               'ContinuousMove' => 'ONVIF::PTZ::Elements::ContinuousMove',
               'GetStatusResponse/PTZStatus/Position' => 'ONVIF::PTZ::Types::PTZVector',
               'GetPresetTourOptionsResponse/Options/StartingCondition/RecurringTime' => 'ONVIF::PTZ::Types::IntRange',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/ZoomSpeedSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'ModifyPresetTour/PresetTour/StartingCondition/RecurringDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::duration',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/AbsoluteZoomPositionSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetPresetTourOptionsResponse/Options/StartingCondition/Direction' => 'ONVIF::PTZ::Types::PTZPresetTourDirection',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/AbsolutePanTiltPositionSpace/XRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetConfigurationsResponse/PTZConfiguration/PanTiltLimits/Range/YRange' => 'ONVIF::PTZ::Types::FloatRange',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces' => 'ONVIF::PTZ::Types::PTZSpaces',
               'GetConfigurationResponse/PTZConfiguration/PanTiltLimits/Range/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'RemovePreset' => 'ONVIF::PTZ::Elements::RemovePreset',
               'GetConfigurationsResponse/PTZConfiguration/DefaultRelativeZoomTranslationSpace' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetNodeResponse/PTZNode/Extension/SupportedPresetTour/PTZPresetTourOperation' => 'ONVIF::PTZ::Types::PTZPresetTourOperation',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/ContinuousZoomVelocitySpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetPresetTourOptionsResponse/Options/TourSpot/PresetDetail/PanTiltPositionSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/PanTiltSpeedSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/PanTiltSpeedSpace/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/AbsolutePanTiltPositionSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetTourResponse/PresetTour/TourSpot/PresetDetail/PTZPosition/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'SetConfiguration/PTZConfiguration/DefaultPTZSpeed/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/AbsolutePanTiltPositionSpace' => 'ONVIF::PTZ::Types::Space2DDescription',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/PanTiltSpeedSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetPresetTourResponse/PresetTour/Status/CurrentTourSpot/PresetDetail/TypeExtension' => 'ONVIF::PTZ::Types::PTZPresetTourTypeExtension',
               'GetConfigurationsResponse/PTZConfiguration/ZoomLimits' => 'ONVIF::PTZ::Types::ZoomLimits',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/RelativePanTiltTranslationSpace/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'Stop/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/PanTiltLimits/Range/URI' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'GetConfigurationsResponse/PTZConfiguration/Extension' => 'ONVIF::PTZ::Types::PTZConfigurationExtension',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/ZoomLimits/Range/XRange/Min' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'ModifyPresetTour/PresetTour/Status/CurrentTourSpot/Speed/Zoom' => 'ONVIF::PTZ::Types::Vector1D',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/PanTiltSpeedSpace/XRange/Max' => 'SOAP::WSDL::XSD::Typelib::Builtin::float',
               'GetNodesResponse/PTZNode' => 'ONVIF::PTZ::Types::PTZNode',
               'GetPresetToursResponse/PresetTour/Status/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourStatusExtension',
               'GetStatusResponse/PTZStatus/MoveStatus/Zoom' => 'ONVIF::PTZ::Types::MoveStatus',
               'GetNodeResponse/PTZNode/SupportedPTZSpaces/ZoomSpeedSpace' => 'ONVIF::PTZ::Types::Space1DDescription',
               'GetPresets' => 'ONVIF::PTZ::Elements::GetPresets',
               'RelativeMove/ProfileToken' => 'ONVIF::PTZ::Types::ReferenceToken',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Extension' => 'ONVIF::PTZ::Types::PTZConfigurationOptions2',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions' => 'ONVIF::PTZ::Types::PTZConfigurationOptions',
               'GetConfigurationResponse/PTZConfiguration/DefaultPTZSpeed' => 'ONVIF::PTZ::Types::PTZSpeed',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'GetPresetTourOptionsResponse/Options/TourSpot/StayTime' => 'ONVIF::PTZ::Types::DurationRange',
               'GetNodesResponse/PTZNode/SupportedPTZSpaces/ZoomSpeedSpace' => 'ONVIF::PTZ::Types::Space1DDescription',
               'ModifyPresetTour/PresetTour/TourSpot/PresetDetail' => 'ONVIF::PTZ::Types::PTZPresetTourPresetDetail',
               'GetCompatibleConfigurationsResponse/PTZConfiguration/Extension' => 'ONVIF::PTZ::Types::PTZConfigurationExtension',
               'ModifyPresetTour/PresetTour/Extension' => 'ONVIF::PTZ::Types::PTZPresetTourExtension',
               'GetPresetToursResponse/PresetTour/Name' => 'ONVIF::PTZ::Types::Name',
               'GetPresetTourResponse/PresetTour/Status/CurrentTourSpot/Speed/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'AbsoluteMove/Position/PanTilt' => 'ONVIF::PTZ::Types::Vector2D',
               'GetConfigurationOptionsResponse/PTZConfigurationOptions/Spaces/ContinuousPanTiltVelocitySpace/XRange' => 'ONVIF::PTZ::Types::FloatRange'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

ONVIF::PTZ::Typemaps::PTZ - typemap for PTZ

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

